<?php
session_start(); // Start the session

require_once("conn.php"); // Ensure the database connection is included

// Check if the checkout form was submitted
if (isset($_POST['checkout'])) {
    // Sanitize and validate user inputs
    $name = htmlspecialchars(trim($_POST['name']));
    $email = filter_var(trim($_POST['email']), FILTER_VALIDATE_EMAIL);
    $phoneNumber = htmlspecialchars(trim($_POST['phone_number']));
    $referenceCode = htmlspecialchars(trim($_POST['teller_number']));
    $region = htmlspecialchars(trim($_POST['region']));
    $province = htmlspecialchars(trim($_POST['province']));
    $zone = htmlspecialchars(trim($_POST['zone']));

    if (!$email) {
        echo '<script>alert("Invalid email address."); window.location.href = "newregistration.php";</script>';
        exit();
    }

    // Initialize cart total
    $cartTotal = 0;
    $productQuantities = []; // Array to hold quantities for each product

    // Fetch product details from the database
    $stmt = $conn->query("SELECT id, name FROM products");
    $productMapping = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // Process cart items
    if (!empty($_SESSION['cart'])) {
        foreach ($_SESSION['cart'] as $item) {
            $itemPrice = $item['price'];
            $itemQuantity = $item['quantity'];
            $productId = $item['id'];

            // Store quantities of each product
            if (!isset($productQuantities[$productId])) {
                $productQuantities[$productId] = 0;
            }
            $productQuantities[$productId] += $itemQuantity;

            // Calculate cart total
            $cartTotal += $itemPrice * $itemQuantity;
        }
    } else {
        echo '<script>alert("Your cart is empty. Please add items before proceeding to checkout."); window.location.href = "shop.php";</script>';
        exit();
    }

    // Check if the cart has at least one item
    if (array_sum($productQuantities) < 1) {
        echo '<script>alert("Sorry, the minimum number of Registration you can book is 1."); window.location.href = "newregistration.php";</script>';
        exit();
    }

    // Dynamically fetch product columns in the registration table
    $stmt = $conn->query("DESCRIBE registration");
    $columns = $stmt->fetchAll(PDO::FETCH_ASSOC);
    $productColumns = [];

    // Find the product-related columns in the registration table
    foreach ($columns as $column) {
        if (strpos($column['Field'], '_ticket') !== false) {
            $productColumns[] = $column['Field']; // e.g., children's_ticket, teen_ticket, etc.
        }
    }

    // Build the dynamic SQL to check for incomplete registrations
    $incompleteCondition = [];
    foreach ($productColumns as $productColumn) {
        $incompleteCondition[] = "$productColumn != {$productColumn}c"; // Compare with the completed column
    }

    // Check if the province has incomplete registrations
    $incompleteSql = "SELECT * FROM registration WHERE province = ? AND (" . implode(' OR ', $incompleteCondition) . ")";
    $stmt = $conn->prepare($incompleteSql);
    $stmt->execute([$province]);
    $incompleteRegistration = $stmt->fetch();

    if ($incompleteRegistration) {
        echo '<script>alert("You cannot generate another RRR code until you complete the previous registration for this province."); window.location.href = "regcontinue.php";</script>';
        exit();
    }

    // Check if a similar record already exists
    $stmt = $conn->prepare("SELECT COUNT(*) FROM registration WHERE name = ? AND email = ? AND phone_number = ? AND password = ?");
    $stmt->execute([$name, $email, $phoneNumber, $referenceCode]);
    $recordExists = $stmt->fetchColumn();

    if ($recordExists) {
        echo '<script>alert("A similar registration already exists. Please avoid duplicate entries."); window.location.href = "newregistration.php";</script>';
        exit();
    }

    // Get the current date and time
    $registrationDateTime = date("l, jS F - h:i:s A"); // e.g., Thursday, 29th August - 06:27:27 PM
    $registrationYear = date("Y"); // e.g., 2024

    // Dynamically build the columns for product quantities in the registration table
    $columnsStr = [];
    $values = [];
    foreach ($productQuantities as $productId => $quantity) {
        // Fetch the product name to generate dynamic column names
        $stmt = $conn->prepare("SELECT name FROM products WHERE id = ?");
        $stmt->execute([$productId]);
        $product = $stmt->fetch();

        if ($product) {
            $productName = strtolower(str_replace(' ', '_', $product['name'])); // Convert to a valid column name (e.g., children's_ticket)
            $columnsStr[] = $productName;  // Add the column name
            $values[] = $quantity;         // Add the quantity value
        }
    }

    // Prepare the dynamic query to insert the registration
    $columnsStr = implode(', ', $columnsStr);
    $placeholders = str_repeat('?, ', count($values) - 1) . '?';
    
    // Insert the registration details dynamically
    $stmt = $conn->prepare("INSERT INTO registration (name, email, phone_number, password, zone, region, province, $columnsStr, amount, date, year) VALUES (?, ?, ?, ?, ?, ?, ?, $placeholders, ?, ?, ?)");
    $stmt->execute(array_merge([
        $name,
        $email,
        $phoneNumber,
        $referenceCode,
        $zone,
        $region,
        $province,
    ], $values, [$cartTotal, $registrationDateTime, $registrationYear]));

    // Clear the cart after successful registration
    unset($_SESSION['cart']);

    // Retrieve the last inserted ID
    $registrationId = $conn->lastInsertId();

    // Redirect to summary page
    echo '<script>
        alert("Thank you, you have booked ' . array_sum($productQuantities) . ' Registration Tickets.");
        window.location.href = "summary.php?registration_id=' . htmlspecialchars($referenceCode, ENT_QUOTES, 'UTF-8') . '";
    </script>';
    exit(); // Ensure the script stops after redirection
}
?>
