<?php
session_start(); // Start the session to access session variables

// Include database connection (adjust path as needed)
include 'conn.php';

function createVirtualAccount($userEmail, $userPhoneNumber, $bvn, $nin, $province, $region) {
    global $conn; // Make $conn accessible within this function

    // Check if an account for the province already exists
    $stmt = $conn->prepare("SELECT * FROM virtual_accounts WHERE province = ?");
    $stmt->execute([$province]);
    $existingAccount = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($existingAccount) {
        throw new Exception('An account already exists for this province.');
    }

    $apiKey = 'FLWSECK-b9a481e9b6a9e2b80ebb251b57534414-191baae22e3vt-X'; // Use your actual API key
    $virtualAccountUrl = 'https://api.flutterwave.com/v3/virtual-account-numbers';

    $headers = [
        "Authorization: Bearer $apiKey",
        "Content-Type: application/json"
    ];

    $virtualAccountData = [
        "email" => $userEmail,
        "is_permanent" => true,
        "phonenumber" => $userPhoneNumber,
        "tx_ref" => uniqid(),
        "firstname" => $province, // Use province as first name
        "lastname" => "$province/$region", // Use province and region in last name
        "narration" => "Account for $province",
        "bvn" => $bvn ?: null, // Use BVN if available
        "nin" => $nin ?: null // Use NIN if available
    ];

    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $virtualAccountUrl);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_POST, 1);
    curl_setopt($ch, CURLOPT_POSTFIELDS, json_encode($virtualAccountData));
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);

    $virtualAccountResponse = curl_exec($ch);
    $error = curl_error($ch);
    $httpCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    curl_close($ch);

    if ($error) {
        throw new Exception('cURL Error: ' . $error);
    }

    $virtualAccountResult = json_decode($virtualAccountResponse, true);

    if ($httpCode === 200 && $virtualAccountResult['status'] === 'success') {
        $data = $virtualAccountResult['data'];

        // Insert virtual account into the database
        $stmt = $conn->prepare("INSERT INTO virtual_accounts (account_number, bank_name, account_status, frequency, created_at, note, province, region, amount) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?)");
        $stmt->execute([
            $data['account_number'],
            $data['bank_name'],
            $data['account_status'] ?? 'active', // Provide a default value if not present
            $data['frequency'] ?? 0, // Default value
            $data['created_at'] ?? date('Y-m-d H:i:s'), // Default value
            $data['note'] ?? '', // Default value
            $province,
            $region,
            $data['amount'] ?? 0 // Default value
        ]);

        echo '<script>alert("Virtual account created successfully!"); window.location.href = "dashboardmin.php";</script>';
    } else {
        $errorMessage = isset($virtualAccountResult['message']) ? $virtualAccountResult['message'] : 'Unknown error';
        throw new Exception('Error creating virtual account: ' . $errorMessage);
    }
}

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $userEmail = $_POST['email'] ?? '';
    $userPhoneNumber = $_POST['phone_number'] ?? '';
    $bvn = $_POST['bvn'] ?? '';
    $nin = $_POST['nin'] ?? ''; // Get NIN from form
    $province = $_SESSION['pro'] ?? 'DefaultProvince';
    $region = $_SESSION['reg'] ?? 'DefaultRegion';

    try {
        createVirtualAccount($userEmail, $userPhoneNumber, $bvn, $nin, $province, $region);
    } catch (Exception $e) {
        echo '<script>alert("'.$e->getMessage().'"); window.location.href = "dashboardmin.php";</script>';
    }
}
?>
