<?php
session_start(); // Start the session

// Include your database connection file
require_once('conn.php');

// Check if the user is logged in and has the required session variables
if (!isset($_SESSION['reg']) || !isset($_SESSION['pro']) || !isset($_SESSION['zone'])) {
    // Redirect to the login page if not logged in
    header("Location: index.php"); // Change to your login page URL
    exit();
}
$freshLogin = isset($_SESSION['freshLogin']) && $_SESSION['freshLogin'];
// Optionally, you can add additional checks for user roles or permissions
// if ($_SESSION['user_role'] != 'admin') {
//     // Redirect or show an error message
//     header("Location: unauthorized.php"); // Change to an appropriate page
//     exit();
// }

$session = $_SESSION['pro'];
$currentYear = date('Y'); // Get the current year

// Query for Children Category
$query_children = "
    SELECT 
        SUM(children1) AS total_children1,
        SUM(children2) AS total_children2,
        SUM(children3) AS total_children3
    FROM children
    WHERE province = :session 
          AND year = :currentYear
          AND EXISTS (
              SELECT 1 FROM bank 
              WHERE bank.rrr = children.password 
              AND bank.status = 'Approved'
          )
";
$stmt_children = $conn->prepare($query_children);
$stmt_children->bindParam(':session', $session);
$stmt_children->bindParam(':currentYear', $currentYear);
$stmt_children->execute();
$children_data = $stmt_children->fetch(PDO::FETCH_ASSOC);

// Query for Teens Category
$query_teens = "
    SELECT 
        SUM(teens1) AS total_teens1,
        SUM(teens2) AS total_teens2
    FROM teens
    WHERE province = :session 
          AND year = :currentYear
          AND EXISTS (
              SELECT 1 FROM bank 
              WHERE bank.rrr = teens.password 
              AND bank.status = 'Approved'
          )
";
$stmt_teens = $conn->prepare($query_teens);
$stmt_teens->bindParam(':session', $session);
$stmt_teens->bindParam(':currentYear', $currentYear);
$stmt_teens->execute();
$teens_data = $stmt_teens->fetch(PDO::FETCH_ASSOC);

// Query for Teachers Category
$query_teachers = "
    SELECT COUNT(*) AS total_teachers
    FROM teachers
    WHERE province = :session 
          AND year = :currentYear
          AND EXISTS (
              SELECT 1 FROM bank 
              WHERE bank.rrr = teachers.password 
              AND bank.status = 'Approved'
          )
";
$stmt_teachers = $conn->prepare($query_teachers);
$stmt_teachers->bindParam(':session', $session);
$stmt_teachers->bindParam(':currentYear', $currentYear);
$stmt_teachers->execute();
$teachers_data = $stmt_teachers->fetch(PDO::FETCH_ASSOC);

// Query for Pending Registrations
$query_pending = "
    SELECT COUNT(*) AS total_pending
    FROM bank
    WHERE province = :session 
          AND status = 'Pending'
          AND year = :currentYear
";

try {
    $stmt_pending = $conn->prepare($query_pending);
    $stmt_pending->bindParam(':session', $session);
    $stmt_pending->bindParam(':currentYear', $currentYear);
    $stmt_pending->execute();
    $pending_data = $stmt_pending->fetch(PDO::FETCH_ASSOC);

    if ($pending_data === false) {
        throw new Exception("Error fetching pending registrations.");
    }

    $total_pending = $pending_data['total_pending'];
} catch (Exception $e) {
    echo "Error: " . $e->getMessage();
}

// Query for Approved Registrations
$query_approved = "
    SELECT COUNT(*) AS total_approved
    FROM bank
    WHERE province = :session 
          AND status = 'Approved'
          AND year = :currentYear
";

try {
    $stmt_approved = $conn->prepare($query_approved);
    $stmt_approved->bindParam(':session', $session);
    $stmt_approved->bindParam(':currentYear', $currentYear);
    $stmt_approved->execute();
    $approved_data = $stmt_approved->fetch(PDO::FETCH_ASSOC);

    if ($approved_data === false) {
        throw new Exception("Error fetching approved registrations.");
    }

    $total_approved = $approved_data['total_approved'];
} catch (Exception $e) {
    echo "Error: " . $e->getMessage();
}


// // Output results
// echo "Pending Registrations: " . (isset($total_pending) ? $total_pending : 'No data');
// echo "Approved Registrations: " . (isset($total_approved) ? $total_approved : 'No data');

?>


<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>RCCG DTCE | Co-ordinator's Dashboard</title>

    <!-- Dependencies -->
    <link rel="stylesheet" href="../plugins/fontawesome-free/css/all.min.css">
    <link rel="stylesheet" href="../plugins/icheck-bootstrap/icheck-bootstrap.min.css">
    <link rel="stylesheet" href="../plugins/password-requirement/css/jquery.passwordRequirements.css">
    <link rel="stylesheet" href="../dist/css/adminlte.min.css">
    <link rel="stylesheet" href="../cookies/cookieconsent.css">
    <link rel="stylesheet" href="../plugins/sweetalert2-theme-bootstrap-4/bootstrap-4.min.css">
    <link rel="stylesheet" href="../dist/css/custom.css">
    <link rel="stylesheet" href="../dist/css/login_style.css">
    <link rel="stylesheet" href="../assets/css/mystyle.css">
    <link rel="stylesheet" href="../dist/css/animate.min.css">
    <link href="../plugins/intl-tel-input-17.0.0/build/css/intlTelInput.min.css" rel="stylesheet" type="text/css" />
    <link rel="shortcut icon" href="../dist/img/icon2.png" type="image/x-icon">
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>

    <!-- Include ApexCharts CSS -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/apexcharts@3.27.3/dist/apexcharts.css">
    <link rel="shortcut icon" href="../dist/img/icon2.png" type="image/x-icon">


    <!-- AdminLTE -->
    <script src="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/js/adminlte.min.js"></script>


    <style>
        .mb-custom {
            margin-bottom: 1.5rem;
            /* Adjust this value to control spacing between rows */
        }

        .first-row-spacing {
            margin-top: 2rem;
            /* Adjust this value to control spacing before the first row */
        }

        /* Positioning the toast at the top-right corner */
        .toast-container {
            position: fixed;
            top: 20px;
            right: 20px;
            z-index: 1050;
        }

        .event-card {
            border-radius: 10px;
            overflow: hidden;
            box-shadow: 0px 4px 10px rgba(0, 0, 0, 0.1);
        }

        .countdown {
            display: flex;
            justify-content: space-between;
            margin-top: 15px;
        }

        .countdown-box {
            border: 2px solid #000;
            border-radius: 5px;
            padding: 10px;
            text-align: center;
            min-width: 50px;
            font-size: 1em;
            color: #000;
        }

        .dark-mode .countdown-box {
            border: 2px solid white;
            border-radius: 5px;
            padding: 10px;
            text-align: center;
            min-width: 50px;
            font-size: 1em;
            color: white;
        }

        .dark-mode .event-card {
            color: white;
            background: black;
        }

        .dark-mode .btn-primary,
        .btn-secondary,
        .btn-danger {
            color: white;
            background: black;
            border: 2px solid #000;
        }

        .dark-mode .btn-primary {
            color: white;
            background: black;
            border: 2px solid #000;

        }

        .dark-mode small {
            color: white;
            font-weight: bold;
        }

        .light-mode small {
            color: black;
            font-weight: bold;
        }


        .countdown-box span {
            display: block;
            font-size: 0.8em;
            color: #666;
        }

        .dark-mode .countdown-box span {
            display: block;
            font-size: 0.8em;
            color: white;
        }

        /* Base Styles for Carousel Controls */
        .carousel-control-prev,
        .carousel-control-next {
            position: absolute;
            top: 50%;
            transform: translateY(-50%);
            background: none;
            /* Remove background */
            border: none;
            /* Remove border */
            padding: 10px;
            /* Increased padding for better clickability */
            border-radius: 50%;
            /* Circular buttons */
            z-index: 10;
            /* Ensure controls are above other elements */
            font-size: 24px;
            /* Font size for arrows */
            color: inherit;
            /* Inherit color from parent, adjust as needed */
        }

        /* Remove default Bootstrap arrow icons */
        .carousel-control-prev-icon,
        .carousel-control-next-icon {
            display: none;
            /* Hide default icons */
        }

        /* Custom Arrow Styling */
        .carousel-control-prev::before,
        .carousel-control-next::before {
            content: '';
            display: inline-block;
            width: 0;
            /* Arrow width */
            height: 0;
            /* Arrow height */
            border-style: solid;
        }

        .carousel-control-prev::before {
            border-width: 10px 15px 10px 0;
            border-color: transparent #000 transparent transparent;
            /* Arrow pointing left */
        }

        .carousel-control-next::before {
            border-width: 10px 0 10px 15px;
            border-color: transparent transparent transparent #000;
            /* Arrow pointing right */
        }

        /* Dark Mode Styles */
        .dark-mode .carousel-control-prev::before,
        .dark-mode .carousel-control-next::before {
            border-color: transparent #fff transparent transparent;
            /* White arrows for dark mode */
        }

        /* Light Mode Styles */
        .light-mode .carousel-control-prev::before,
        .light-mode .carousel-control-next::before {
            border-color: transparent #000 transparent transparent;
            /* Black arrows for light mode */
        }



        /*    new */
        .card {
            width: 100%;
            max-width: 1000px;
        }

        .profile-pic {
            width: 120px;
            height: 120px;
            object-fit: cover;
            border-radius: 50%;
        }

        .card-body {
            padding: 1.5rem;
        }

        .info-col {
            display: flex;
            align-items: center;
            padding-right: 1rem;
        }

        .info-col span {
            margin-right: 0.5rem;
        }

        .card-widgets a {
            color: #007bff;
            margin-right: 10px;
        }

        .card-widgets a:hover {
            color: #0056b3;
        }

        .card-body {
            padding: 20px;
        }

        .account-number,
        .balance {
            font-size: 1.2rem;
            font-weight: bold;
        }

        .card-header-title {
            font-size: 1.5rem;
        }

        .ripple {
            position: absolute;
            border-radius: 50%;
            background: rgba(0, 0, 0, 0.3);
            transform: scale(0);
            animation: ripple-effect 0.5s linear;
        }

        @keyframes ripple-effect {
            to {
                transform: scale(2);
                opacity: 0;
            }
        }

        .card-img-top {
            transition: transform 0.3s ease;
            /* Smooth transition for zoom effect */
        }

        .card:hover .card-img-top {
            transform: scale(1.1);
            /* Scale the image on hover */
        }

        /*help tools*/
        /* Common styles for the .helpful-tool-text and .helpful-tool-box */
        .helpful-tool-text {
            font-weight: 500;
            font-size: 1rem;
            color: #555555;
        }

        .helpful-tool-box {
            border: 4px solid hsla(212, 99%, 26%, 0.2);
            display: flex;
            flex-direction: column;
            justify-content: space-between;
            padding: 1rem;
            transition: all 0.2s;
            margin: auto;
            margin-right: 1rem;
            /* background-color: white; */
        }

        .base-theme .helpful-tool-box {
            border: 4px solid rgba(254, 243, 235, 1);
        }

        #private .helpful-tool-box {
            border: 4px solid hsla(0, 0%, 100%, 0.2);
        }

        /* Default styles for larger screens */
        .helpful-tool-box {
            width: 176px;
            height: 151px;
        }

        /* Media query for smaller screens */
        @media (max-width: 768px) {
            .helpful-tool-box {
                width: 100%;
                /* Make the card width 100% of the parent container */
                height: auto;
                /* Adjust height as needed, content will dictate height */
                margin: 0.5rem;
                /* Reduce margin for spacing on smaller screens */
            }

            /* You can further adjust styles for smaller screens as needed */
        }

        /* Hover and focus styles remain the same as in your original code */
        .helpful-tool-box:hover,
        .helpful-tool-box:focus,
        .helpful-tool-box:active {
            background: #2c7cf0;
            box-shadow: 0px 30px 50px #2c7cf0;
            color: white;
            text-decoration: none;
            border: 0;
            transform: scale(1.02);
        }

        #card a:hover .helpful-tool-text {
            color: #ffffff;
            /* Change this to match the fill color of the SVG */
        }

        .helpful-tool-box:focus,
        .helpful-tool-box:active {
            transform: scale(1);
        }

        .helpful-tool-box:hover>svg.tool-icon>g>path,
        .helpful-tool-box:focus>svg.tool-icon>g>path {
            fill: #ffffff;
        }

        .helpful-tool-box:hover>.helpful-tool-text,
        .helpful-tool-box:focus>.helpful-tool-text {
            color: #ffffff;
        }

        .helpful-tool-box:hover>svg.tool-icon>path,
        .helpful-tool-box:focus>svg.tool-icon>path {
            fill: #ffffff;
        }

        .helpful-tool-text:hover>svg.tool-icon>path,
        .helpful-tool-text:focus>svg.tool-icon>path {
            fill: #ffffff;
        }

        /* DTCE BUTTONS */
        .btn {
            border-radius: 0;
            /* font-weight: bold; */
            transition: all 0.2s;
        }

        .form-control {
            border-radius: 0;
        }

        .btn:hover {
            transform: translateY(-1px);
            opacity: 0.9;
        }

        .main-button.btn {
            color: #2c7cf0;
            border-radius: 0px;
            border: 2px solid #2c7cf0
        }

        .main-button:hover {
            color: white;
            background: #2c7cf0
        }

        .main-button.button-filled.btn {
            background: #2c7cf0 !important;
        }

        .main-button.button-filled.btn:hover {
            color: #2c7cf0 !important;
            background: transparent !important;
        }

        .main-button.button-outlined:hover {
            background: #2c7cf0 !important;
        }

        .button-outlined {
            background: transparent !important;
        }

        .button-filled {
            color: white !important;
        }

        .video-card {
            position: relative;
            overflow: hidden;
            border: 1px solid #ddd;
            border-radius: 5px;
            box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
            cursor: pointer;
        }

        .video-card img {
            width: 100%;
            height: auto;
            border-radius: 5px 5px 0 0;
            transition: opacity 0.3s ease;
        }

        .video-iframe {
            display: none;
            /* Initially hide the iframe */
            width: 100%;
            height: 200px;
            /* Adjust height as necessary */
            border: none;
            border-radius: 5px;
        }

        .video-card-body {
            padding: 15px;
        }

        /* Main theme Default light mode (bootstrap defaults) */
        body {
            background-color: #ffffff;
            color: #000000;
            transition: background-color 0.3s, color 0.3s;
        }

        
        a {
            color:rgb(12, 12, 12);
        }

        a:hover {
            color: #0056b3;
        }

        /* Dark Mode - Links */
.dark-mode .strip_2 a {
    color: rgb(241, 239, 239) !important; /* Light color for better contrast */
    text-decoration: none; /* Optional: Removes underline for a cleaner look */
}

/* Dark Mode - Links on Hover */
.dark-mode .strip_2 a:hover {
    color: #4a90e2 !important; /* A softer blue for better readability */
    text-decoration: underline; /* Optional: Adds underline on hover */
}


        .light-mode .province-initials {
            background-color: #007bff !important;
            color: white !important;
            /* border: 1px solid white !important; */
        }

        .light-mode .alert,
        .dropdown-menu,
        .dropdown-menu-lg,
        .dropdown-menu-right,
        .dropdown-item {
            background-color: white !important;
            color: black !important;
            border-color: #444 !important;
        }

        /* Dark Mode */
        .dark-mode {
            background-color: #121212 !important;
            color: #ffffff !important;
        }

        /* Dark mode for links */
        .dark-mode a {
            color: rgb(247, 249, 252) !important;
        }

        .dark-mode a:hover {
            color: rgb(243, 248, 253) !important;
        }

        /* Dark mode for navigation bar */
        .dark-mode .navbar {
            background-color: #1e1e1e !important;
            border-bottom: 1px solid #333 !important;
        }

        .dark-mode .navbar a {
            color: white !important;
        }

        .dark-mode .navbar a:hover {
            color: #ccc !important;
        }

        /* Dark mode for buttons */
        .dark-mode .btn {
            background-color: #333 !important;
            color: white !important;
            /* border: 1px solid white !important; */
        }

        .dark-mode .btn:hover {
            background-color: white !important;
        }

        /* Specific button colors in dark mode */
        .dark-mode .btn-primary {
            background-color: rgb(0, 3, 7) !important;
            color: white !important;
        }

        .dark-mode .btn-success {
            background-color: rgb(1, 12, 3) !important;
            color: white !important;
        }

        .dark-mode .btn-danger {
            background-color: rgb(8, 0, 1) !important;
            color: white !important;
        }

        .dark-mode .btn-warning {
            background-color: rgb(2, 1, 0) !important;
            color: white !important;
        }

        .dark-mode .btn-info {
            background-color: rgb(0, 7, 8) !important;
            color: white !important;
        }

        /* Dark mode for tables */
        .dark-mode table {
            background-color: #1e1e1e !important;
            color: white !important;
        }

        .dark-mode thead {
            background-color: #333 !important;
        }

        .dark-mode tbody tr {
            background-color: #2c2c2c !important;
        }

        .dark-mode tbody tr:hover {
            background-color: #3a3a3a !important;
        }

        /* Dark mode for form fields */
        .dark-mode input,
        .dark-mode select,
        .dark-mode textarea {
            background-color: #222 !important;
            color: white !important;
            border: 1px solid white !important;
        }

        .dark-mode input::placeholder,
        .dark-mode textarea::placeholder {
            color: #bbb !important;
        }

        /* Dark mode for modals */
        .dark-mode .modal-content {
            background-color: #1e1e1e !important;
            color: white !important;
        }

        .dark-mode .modal-header {
            border-bottom: 1px solid #333 !important;
        }

        .dark-mode .modal-footer {
            border-top: 1px solid #333 !important;
        }

        /* Dark mode for sidebar (if applicable) */
        .dark-mode .sidebar {
            background-color: #1e1e1e !important;
        }

        .dark-mode .sidebar a {
            color: white !important;
        }

        .dark-mode .sidebar a:hover {
            color: #ccc !important;
        }

        /* Dark mode for alerts */
        .dark-mode .alert,
        .dropdown-menu,
        .dropdown-menu-lg,
        .dropdown-menu-right,
        .dropdown-item {
            background-color: #333 !important;
            color: white !important;
            border-color: #444 !important;
        }


        /* Default (Light Mode) */
        .alert,
        .dropdown-menu,
        .dropdown-menu-lg,
        .dropdown-menu-right,
        .dropdown-item {
            background-color: #ffffff !important;
            /* Light background */
            color: #000000 !important;
            /* Dark text */
            border-color: #ddd !important;
            /* Light border */
        }

        /* Hover effect in light mode */
        .dropdown-item:hover {
            background-color: #f8f9fa !important;
            color: #000000 !important;
        }

        /* Dark Mode */
        .dark-mode .alert,
        .dark-mode .dropdown-menu,
        .dark-mode .dropdown-menu-lg,
        .dark-mode .dropdown-menu-right,
        .dark-mode .dropdown-item {
            background-color: #222 !important;
            /* Dark background */
            color: #ffffff !important;
            /* Light text */
            border-color: #444 !important;
            /* Dark border */
        }

        /* Hover effect in dark mode */
        .dark-mode .dropdown-item:hover {
            background-color: #333 !important;
            color: #ffffff !important;
        }

        /* Light Mode */
        .toast-body,
        .toast-header {
            background-color: #ffffff !important;
            /* White background */
            color: #000000 !important;
            /* Black text */
            border-color: #ddd !important;
            /* Light grey border */
        }
/* Light Mode - Paragraph Specific */


/* Light Mode - Paragraph on Blue Background */
.sidebar-dark-primary p,
.main-sidebar p {
    color: white !important; /* White text on blue backgrounds */
} 

.sidebar-dark-primary .fa,
.main-sidebar .fa {
    color: white !important; /* White text on blue backgrounds */
} 
        /* Light Mode (Default) */
        
        p,
        h1,
        h2,
        h3,
        h4,
        h5,
        h6,
        .card-title,
        .text-dark,
        .text-secondary,
        .text-muted,
        .text-primary {
            color:rgb(12, 0, 0) !important;
            /* Default dark text */
        }


        .fa {
            color:white;
        }
        /* Dark Mode Styles */
        .dark-mode {
            background-color: #121212 !important;
            /* Dark background */
            color: #ffffff !important;
            /* Light text */
        }

        /* Dark Mode Text Colors */
        .dark-mode .fa,
        .dark-mode p,
        .dark-mode h1,
        .dark-mode h2,
        .dark-mode h3,
        .dark-mode h4,
        .dark-mode h5,
        .dark-mode h6,
        .dark-mode .card-title,
        .dark-mode .text-dark,
        .dark-mode .text-secondary,
        .dark-mode .text-muted,
        .dark-mode .text-primary {
            color: #ffffff !important;
            /* White text in dark mode */
        }
        
        .dark-mode .strip-wrapper{
            background-color:none;
            color:black;
        }
        
    
      .strip_2,.strip-wrapper{
            background-color:none;
            color: black;
        }
        

        .card-title,
         .text-dark,
         .text-secondary,
         .text-muted,
         .text-primary {
            color:rgb(7, 6, 6) !important;
            /* White text in dark mode */
        }


        /* Adjust Specific Text Colors in Dark Mode */
        .dark-mode .text-muted {
            color: #b0b0b0 !important;
            /* Slightly gray for muted text */
        }

        .dark-mode .text-primary {
            color:rgb(237, 241, 245) !important;
            /* Lighter blue for better contrast */
        }

        .dark-mode .text-secondary {
            color: #adb5bd !important;
            /* Light grayish text */
        }

        /* Dark Mode Background for Cards & Containers */
        .dark-mode .card,
        .dark-mode .modal-content,
        .dark-mode .dropdown-menu,
        .dark-mode .toast-body,
        .dark-mode .toast-header {
            background-color: #222 !important;
            color: white !important;
            border-color: #444 !important;
        }

        /* Dark Mode FA Icons */
        .dark-mode .fa {
            color: #ffffff !important;
            /* White icons in dark mode */
        }

        /* Dark Mode Specific Icons */
        .dark-mode .fa-calendar {
            color:rgb(236, 235, 229) !important;
            /* Yellow */
        }
        .fa-calendar {
            color:#007bff !important;
            /* Yellow */
        }

        .dark-mode .fa-user {
            color:rgb(242, 247, 248) !important;
            /* Bootstrap info blue */
        }

        .dark-mode .fa-cog, .fa-clock  {
            color: #f8f9fa !important;
            /* Light gray */
        }
         .fa-cog, .fa-clock, .fa-user  {
            color:rgb(1, 5, 10) !important;
            /* Light gray */
        }

        /* Dark Mode Buttons */
        .dark-mode .btn {
            background-color: #333 !important;
            color: #ffffff !important;
            border: 1px solid #555 !important;
        }

        .dark-mode .btn-primary {
            background-color:rgb(11, 12, 12) !important;
            border-color:rgb(8, 8, 8) !important;
        }

        .dark-mode .btn-secondary {
            background-color: #6c757d !important;
            border-color: #6c757d !important;
        }

        /* Hover Effects */
        .dark-mode .btn:hover {
            background-color: #444 !important;
        }

        .dark-mode .btn-primary:hover {
            background-color:rgb(17, 17, 19) !important;
        }

        .dark-mode .btn-secondary:hover {
            background-color: #5a6268 !important;
        }



        /* Toast header specific styling */
        .toast-header {
            font-weight: bold;
            border-bottom: 1px solid #ddd !important;
        }

        /* Dark Mode */
        .dark-mode .toast-body,
        .dark-mode .toast-header {
            background-color: #222 !important;
            /* Dark background */
            color: #ffffff !important;
            /* White text */
            border-color: #444 !important;
            /* Dark grey border */
        }
        
         /* Light Mode - Toast Styling */
.toast-body,
.toast-header {
    background-color: white !important; /* White background */
    color: rgb(15, 15, 15) !important; /* Dark text */
    border-color: #ddd !important; /* Light grey border */
}

/* Light Mode - Toast Header */
.toast-header {
    font-weight: bold;
    border-bottom: 1px solid #ccc !important; /* Light grey separator */
}

        /* Toast header specific styling */
        .dark-mode .toast-header {
            font-weight: bold;
            border-bottom: 1px solid #444 !important;
        }
        


        /* Dark mode for card components */
        .dark-mode .card {
            background-color: #222 !important;
            color: white !important;
            /* border: 1px solid white !important; */
        }

        .dark-mode .card-header {
            background-color: #1e1e1e !important;
        }

        /* Toggle Button Fix */
        .dark-mode #theme-toggle {
            /* background-color: #222 !important; */
            color: white !important;
            /* border: 1px solid white !important; */
        }

        .dark-mode .badge-danger,
        .province-initials {
            background-color: white !important;
            color: black !important;
            /* border: 1px solid white !important; */
        }
    </style>


</head>

<body class="hold-transition sidebar-mini layout-fixed">

<div class="wrapper">
    <!-- Navbar -->
    <nav class="main-header navbar navbar-expand-lg navbar-light">
        <div class="container-fluid">
            <!-- Navbar Toggler for Mobile -->
            <button class="navbar-toggler" type="button" data-toggle="collapse" data-target="#navbarNav"
                aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
                <span class="navbar-toggler-icon"></span>
            </button>

            <!-- Left Navbar Links -->
            <a href="#" class="navbar-brand">
                <img src="../dist/img/dtce.png" alt="Logo" style="height: 40px;">
            </a>

            <?php
            include 'conn.php';
            $province_name = $_SESSION['pro']; // Get the province name from the session

            // Fetch the count of unread notifications for this province
            $stmt = $conn->prepare("SELECT COUNT(*) as count FROM notifications WHERE province = :province AND is_read = 0");
            $stmt->bindValue(':province', $province_name);
            $stmt->execute();
            $count = $stmt->fetch(PDO::FETCH_ASSOC)['count'];
            ?>

            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav">
                    <li class="nav-item">
                        <a class="nav-link" data-widget="pushmenu" href="#" role="button">
                            <i class="fas fa-bars"></i>
                        </a>
                    </li>
                </ul>

                <!-- Centered Search Form -->
                <form class="form-inline mx-auto">
                    <input class="form-control mr-sm-2" type="search" placeholder="Search" aria-label="Search">
                    <button class="btn btn-outline-primary my-2 my-sm-0" type="submit">
                        <i class="fas fa-search"></i>
                    </button>
                </form>

                <!-- Right Navbar Links -->
                <ul class="navbar-nav ml-auto">
                    <li class="nav-item">
                        <a class="nav-link" href="#">
                            <img src="../dist/img/ng3.webp" alt="Flag" style="width: 35px;">
                        </a>
                    </li>

                    <li class="nav-item dropdown">
                        <a class="nav-link dropdown-toggle" href="#" id="notificationDropdown" role="button"
                            data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
                            <i class="fas fa-bell">
                                <span class="badge badge-danger"><?php echo $count; ?></span>
                            </i>
                        </a>
                        <div class="dropdown-menu dropdown-menu-right" aria-labelledby="notificationDropdown"
                            id="notificationList">
                            <!-- Notifications will be loaded here -->
                        </div>
                    </li>

                    <li class="nav-item">
                        <a class="nav-link" href="#" id="theme-toggle">
                            <i id="theme-icon" class="fas fa-sun"></i> <!-- Default icon is sun -->
                        </a>
                    </li>

                    <li class="nav-item dropdown">
                        <a class="nav-link d-flex align-items-center dropdown-toggle" data-toggle="dropdown" href="#">
                            <?php
                            // Extract initials from the province name
                            $province = $_SESSION["pro"];
                            $province_parts = explode(" ", $province);
                            $initials = strtoupper(substr($province_parts[0], 0, 1)) . strtoupper(substr($province_parts[1], 0, 1));
                            $number = isset($province_parts[2]) ? $province_parts[2] : '';

                            // Display the initials and the number
                            echo '<div class="province-initials"
                                style="background-color: #007bff; color: white; width: 45px; height: 45px; border-radius: 50%; display: flex; justify-content: center; align-items: center; margin-right: 10px; font-weight: bold; font-size: 16px;">';
                            echo $initials . ' ' . $number;
                            echo '</div>';
                            ?>

                            <div style="display: flex; flex-direction: column;">
                                <span class="d-none d-md-inline"><?php echo $_SESSION["pro"] ?></span>
                                <small><?php echo $_SESSION["zone"] ?></small>
                            </div>
                        </a>
                        <div class="dropdown-menu dropdown-menu-lg dropdown-menu-right">
                            <a href="#" class="dropdown-item"><i class="fas fa-user"></i> My Profile</a>
                            <a href="#" class="dropdown-item"><i class="fas fa-cog"></i> Settings</a>
                            <div class="dropdown-divider"></div>
                            <a href="logout.php" class="dropdown-item"><i class="fas fa-sign-out-alt"></i> Logout</a>
                        </div>
                    </li>
                </ul>
            </div>
        </div>
    </nav>
</div>

        <!-- Scripts -->


        <!-- /.navbar -->

        <!-- Main Sidebar Container -->
        <aside class="main-sidebar sidebar-dark-primary elevation-4">
            <!-- Sidebar -->
            <div class="sidebar">
                <!-- Sidebar user panel -->
                <div class="user-panel mt-3 pb-3 mb-3 d-flex">
                    <div class="image">
                        <img src="../dist/img/icon.png" alt="User Image">
                    </div>
                    <div class="info">
                        <a href="#" class="d-block">RCCG DTCE</a>
                    </div>
                </div>

                <!-- Sidebar Menu -->
                <?php
                // Include your database connection file
                include 'conn.php';

                // Fetch menu items, ordered by the 'order' field
                $stmt = $conn->query("SELECT * FROM navbars WHERE status = 'active' ORDER BY `order` ASC");
                $menuItems = $stmt->fetchAll(PDO::FETCH_ASSOC);
                ?>

                <!-- Sidebar Menu -->
                <nav class="mt-2">
                    <ul class="nav nav-pills nav-sidebar flex-column" data-widget="treeview" role="menu" data-accordion="false">
                        <?php foreach ($menuItems as $item): ?>
                            <li class="nav-item">
                                <a href="<?php echo htmlspecialchars($item['link']); ?>" class="nav-link">
                                    <i class="nav-icon fas <?php echo htmlspecialchars($item['icon']); ?>"></i>
                                    <p style="color: white;"><?php echo htmlspecialchars($item['name']); ?></p>
                                </a>
                            </li>
                        <?php endforeach; ?>
                    </ul>
                </nav>


                <!-- /.sidebar-menu -->
            </div>
            <!-- /.sidebar -->
        </aside>

        <!-- Content Wrapper -->
        <div class="content-wrapper">
            <!-- Breadcrumb -->
            <div class="breadcrumb-wrapper">
                <ul class="breadcrumb">
                    <li class="breadcrumb-item"><a href="../../index.php">HOME</a></li>
                    <li class="breadcrumb-item active">Dashboard</li>
                </ul>
            </div>
            <?php include("news.php"); ?>
            <!-- Main content -->

            <section class="content">
                <?php
                include 'conn.php';

                // Fetch the cover picture
                $stmt = $conn->query("SELECT * FROM cover_pic ORDER BY id DESC LIMIT 1");
                $coverPic = $stmt->fetch(PDO::FETCH_ASSOC);

                $imagePath = $coverPic ? $coverPic['image_path'] : './dist/img/bg-login.jpg'; // Default image if none found
                ?>

                <div class="row">
                    <div class="col-sm-12">
                        <div class="profile-bg-picture"
                            style="background-image: url('<?php echo htmlspecialchars($imagePath); ?>');">
                            <div class="picture-bg-overlay"></div>
                        </div>
                    </div>
                </div>
                <br>

                <?php

                require_once('conn.php'); // Ensure the database connection is included

                $province = isset($_SESSION['pro']) ? $_SESSION['pro'] : null;

                // Check if province is set
                if (!$province) {
                    die('Province not set in session.');
                }

                // Fetch virtual account details using province
                $stmt = $conn->prepare("SELECT account_number, bank_name, balance FROM virtual_accounts WHERE province = ?");
                $stmt->execute([$province]);
                $virtualAccount = $stmt->fetch(PDO::FETCH_ASSOC);

                $accountNumber = isset($virtualAccount['account_number']) ? htmlspecialchars($virtualAccount['account_number']) : 'N/A';
                $bankName = isset($virtualAccount['bank_name']) ? htmlspecialchars($virtualAccount['bank_name']) : 'N/A';
                $balance = isset($virtualAccount['balance']) ? htmlspecialchars($virtualAccount['balance']) : 'N/A';
                ?>

                <div class="container-fluid mt-5">
                    <div class="col-12">
                        <div class="section-title">
                            <h3>Annual <span class="alternate">Convention Registration Analysis</span></h3>
                            <p><?php echo Date('Y') ?> General Registration Analysis of
                                <?php echo ucwords(strtolower($_SESSION['pro'])); ?>
                            </p>
                        </div>
                    </div>
                    <div class="row">
                        <!-- Left Column with Bar Chart (Larger) -->
                        <div class="col-lg-8">
                            <div class="card">
                                <div class="card-body">
                                    <div class="card-widgets">
                                        <a href="javascript:;" data-bs-toggle="reload"><i
                                                class="ri-refresh-line"></i></a>
                                        <a data-bs-toggle="collapse" href="#weeklysales-collapse" role="button"
                                            aria-expanded="false" aria-controls="weeklysales-collapse"><i
                                                class="ri-subtract-line"></i></a>
                                        <a href="#" data-bs-toggle="remove"><i class="ri-close-line"></i></a>
                                    </div>
                                    <h5 class="header-title mb-0"><?php echo htmlspecialchars($_SESSION['pro']); ?>
                                        CONVENTION REGISTRATION ANALYSIS (APPROVED REGISTRATIONS)</h5>

                                    <div id="weeklysales-collapse" class="collapse pt-3 show">
                                        <div dir="ltr">
                                            <div id="id-chart" class="apex-charts"
                                                data-colors="#3bc0c3,#1a2942,#d1d7d973"></div>
                                        </div>

                                        <div class="row text-center">
                                            <div class="col">
                                                <p class="text-muted mt-3">Children (1-5)</p>
                                                <h3 class="mb-0">
                                                    <span><?php echo !empty($children_data['total_children1']) ? htmlspecialchars($children_data['total_children1']) : '0'; ?></span>
                                                </h3>
                                            </div>
                                            <div class="col">
                                                <p class="text-muted mt-3">Children (6-8)</p>
                                                <h3 class="mb-0">
                                                    <span><?php echo !empty($children_data['total_children2']) ? htmlspecialchars($children_data['total_children2']) : '0'; ?>
                                                    </span>
                                                </h3>
                                            </div>
                                            <div class="col">
                                                <p class="text-muted mt-3">Children (9-12)</p>
                                                <h3 class="mb-0">
                                                    <span><?php echo !empty($children_data['total_children3']) ? htmlspecialchars($children_data['total_children3']) : '0'; ?></span>
                                                </h3>
                                            </div>
                                            <div class="col">
                                                <p class="text-muted mt-3">Teens (13-15)</p>
                                                <h3 class="mb-0">
                                                    <span><?php echo !empty($teens_data['total_teens1']) ? htmlspecialchars($teens_data['total_teens1']) : '0'; ?>
                                                    </span>
                                                </h3>
                                            </div>
                                            <div class="col">
                                                <p class="text-muted mt-3">Teens (16-above)</p>
                                                <h3 class="mb-0">
                                                    <span><?php echo !empty($teens_data['total_teens2']) ? htmlspecialchars($teens_data['total_teens2']) : '0'; ?>
                                                    </span>
                                                </h3>
                                            </div>
                                            <div class="col">
                                                <p class="text-muted mt-3">Teachers</p>
                                                <h3 class="mb-0">
                                                    <span><?php echo !empty($teachers_data['total_teachers']) ? htmlspecialchars($teachers_data['total_teachers']) : '0'; ?>
                                                    </span>
                                                </h3>
                                            </div>
                                            <div class="col">
                                                <p class="text-muted mt-3">Pending</p>
                                                <h3 class="mb-0">
                                                    <span><?php echo !empty($pending_data['total_pending']) ? htmlspecialchars($pending_data['total_pending']) : '0'; ?>
                                                    </span>
                                                </h3>
                                            </div>
                                            <div class="col">
                                                <p class="text-muted mt-3">Approved</p>
                                                <h3 class="mb-0">
                                                    <span><?php echo !empty($approved_data['total_approved']) ? htmlspecialchars($approved_data['total_approved']) : '0'; ?>
                                                    </span>
                                                </h3>
                                            </div>

                                        </div>
                                    </div>
                                </div> <!-- end card-body-->
                            </div> <!-- end card-->
                        </div> <!-- end col-->
                        <?php
require 'conn.php';

// Get active province from session
$province = $_SESSION['pro'];

// Fetch Approved and Pending registrations count
$query = "SELECT 
            SUM(CASE WHEN status = 'Approved' THEN 1 ELSE 0 END) AS approved_count,
            SUM(CASE WHEN status = 'Pending' THEN 1 ELSE 0 END) AS pending_count,
            SUM(cash) AS total_cash
          FROM bank
          WHERE province = :province";

$stmt = $conn->prepare($query);
$stmt->bindParam(':province', $province, PDO::PARAM_STR);
$stmt->execute();
$result = $stmt->fetch(PDO::FETCH_ASSOC);

$approvedCount = $result['approved_count'] ?? 0;
$pendingCount = $result['pending_count'] ?? 0;
$totalCash = $result['total_cash'] ?? 0;
?>
                        <!-- Right Column with Virtual Account Details (Smaller) -->
                        <div class="col-lg-4">
    <div class="card">
        <div class="card-body">
            <div class="card-widgets">
                <a href="javascript:;" onclick="location.reload();"><i class="ri-refresh-line"></i></a>
                <a data-bs-toggle="collapse" href="#yearly-sales-collapse" role="button" aria-expanded="false" aria-controls="yearly-sales-collapse">
                    <i class="ri-subtract-line"></i>
                </a>
                <a href="#" data-bs-toggle="remove"><i class="ri-close-line"></i></a>
            </div>
            <h5 class="header-title mb-0">REGISTRATION STATUS REPORT</h5>

            <div id="yearly-sales-collapse" class="collapse pt-3 show">
                <div dir="ltr">
                    <div id="yearly-sales-chart" class="apex-charts" data-colors="#3bc0c3,#1a2942,#d1d7d973"></div>
                </div>
                <div class="row text-center">
                    <div class="col">
                        <p class="text-muted mt-3 mb-2">Approved</p>
                        <h4 class="mb-0"><?php echo $approvedCount; ?></h4>
                    </div>
                    <div class="col">
                        <p class="text-muted mt-3 mb-2">Pending</p>
                        <h4 class="mb-0"><?php echo $pendingCount; ?></h4>
                    </div>
                    <div class="col">
                        <p class="text-muted mt-3 mb-2">Total Paid</p>
                        <h4 class="mb-0">₦<?php echo number_format($totalCash, 2); ?></h4>
                    </div>
                </div>
            </div>
        </div> <!-- end card-body-->
    </div> <!-- end card-->
</div> <!-- end col-->
            </div>
            </div>
                <section class="helpful-tools">
                    <div class="container mt-3">
                        <div class="col-12">
                            <div class="section-title">
                                <h3>DTCE <span class="alternate">Help Tools</span></h3>
                                <p>Navigate through your dashboard with the following help tools</p>
                            </div>
                        </div>

                        <!-- HELPFUL TOOLS ROW -->
                        <div class="row">
                            <!-- HELPFUL TOOL -->
                            <div class="col-6 col-md-4 col-lg-3 col-xl-2">
                                <a href="your-link-here">
                                    <div class="card helpful-tool-box">
                                        <!-- <img src="../assets/images/icon.png" class="tool-icon" fill="none" viewbox="0 0 60 " alt="dtce logo" width="60px"> -->
                                        <svg class="tool-icon" fill="none" height="44" viewBox="0 0 35 44" width="35"
                                            xmlns="http://www.w3.org/2000/svg">
                                            <path
                                                d="M12.4408 0.184151C14.8343 -0.689534 17.5651 1.71208 17.0205 4.21123C16.7239 6.92981 13.0097 8.20986 11.0795 6.29588C8.9664 4.60947 9.84416 0.838398 12.4408 0.184151ZM12.3799 2.20379C10.9698 3.09372 11.8597 5.67415 13.5705 5.34499C14.5824 5.48722 15.009 4.54851 15.3707 3.8008C15.2122 3.32941 15.0619 2.86616 14.9156 2.39884C14.176 1.92746 13.1316 1.53328 12.3799 2.20379Z"
                                                fill="#F98537"></path>
                                            <path
                                                d="M21.3972 0.192201C23.62 -0.648974 26.2776 1.40316 26.0176 3.77633C26.1151 6.68997 22.0433 8.42515 20.044 6.26735C17.9837 4.58906 18.7599 0.801749 21.3972 0.192201ZM20.6535 2.74417C20.6251 3.65443 20.7348 4.57688 21.3972 5.2677C22.2953 5.3002 23.5794 5.56434 24.0101 4.50373C24.6928 3.42686 23.7744 1.8136 22.5025 1.85423C21.7548 1.75264 21.2265 2.38251 20.6535 2.74417Z"
                                                fill="#F98537"></path>
                                            <path
                                                d="M29.9673 0.334446C32.2714 -0.823694 35.2582 1.23658 34.9615 3.79668C35.0672 6.60467 31.2595 8.34797 29.1952 6.42587C27.078 4.9467 27.5372 1.23658 29.9673 0.334446ZM29.6219 3.3578C29.2115 5.24334 32.1454 6.16579 32.9541 4.50782C33.5636 3.62601 32.9297 2.66292 32.4055 1.93553C31.2677 1.71609 29.7804 1.96397 29.6219 3.3578Z"
                                                fill="#F98537"></path>
                                            <path
                                                d="M11.7092 8.54714C14.0174 7.1208 17.3862 9.13637 17.0529 11.8834C17.0733 14.6386 13.42 16.3575 11.3273 14.5491C9.23855 13.1553 9.50269 9.68497 11.7092 8.54714ZM12.5545 10.0222C12.2781 10.3473 12.0059 10.6724 11.7336 10.9975C11.7336 11.3551 11.7336 12.0663 11.7336 12.4239C12.0059 12.7327 12.2781 13.0415 12.5504 13.3544C13.416 13.4601 14.2775 13.3504 15.0211 12.8587C15.395 11.8631 15.1552 10.9122 14.57 10.0588C13.8955 10.0548 13.225 10.0385 12.5545 10.0222Z"
                                                fill="#F98537"></path>
                                            <path
                                                d="M20.665 8.55505C22.8269 7.17747 26.025 8.94515 26.0331 11.5093C26.2891 13.9678 23.4811 16.024 21.2136 15.0569C18.3894 14.2238 18.048 9.87573 20.665 8.55505ZM20.6488 10.9729C20.665 11.3346 20.6935 12.0538 20.7057 12.4155C20.9861 12.7325 21.2624 13.0494 21.5468 13.3745C22.8797 13.7646 24.4117 12.9885 24.2614 11.4524C24.0216 9.62379 21.4534 9.50188 20.6488 10.9729Z"
                                                fill="#F98537"></path>
                                            <path
                                                d="M29.9098 16.4958C32.096 15.3376 35.03 17.15 34.969 19.6207C35.3063 22.2377 32.0188 24.2492 29.7798 22.9448C27.1424 21.8151 27.2522 17.5523 29.9098 16.4958ZM30.4096 18.2594C29.1702 19.0071 29.4872 21.0024 30.8079 21.4616C32.1164 21.9736 33.6036 20.5513 33.1241 19.2225C32.8397 18.0318 31.3727 17.7677 30.4096 18.2594Z"
                                                fill="#F98537"></path>
                                            <path
                                                d="M10.9291 18.8523C11.3761 17.5276 13.034 16.6214 14.3751 17.1822C15.4235 17.4951 16.1509 18.5313 16.1549 19.6203C16.2687 23.4158 16.0533 27.2153 16.2565 31.0108C17.5447 29.6901 18.8125 27.7924 20.8891 27.8939C21.7668 27.8208 22.4861 28.3856 23.2054 28.8001C23.441 31.0229 21.8928 32.8556 21.2101 34.8672C20.4787 37.0615 18.8938 38.7561 17.5284 40.5563C16.8051 41.3446 17.053 42.4662 17.0774 43.4333C16.6263 42.9132 15.8745 43.1204 15.2812 43.0351C15.0293 41.3812 15.5779 39.7964 16.732 38.6057C19.1376 36.1066 20.1089 32.7093 21.5068 29.625C18.9507 29.5234 18.1136 32.5346 15.9639 33.388C15.3137 32.6972 14.371 32.0917 14.3669 31.0351C14.2044 27.0081 14.4929 22.9688 14.2287 18.9417C13.6883 18.9702 13.1559 18.9905 12.6277 19.0311C12.4936 22.4283 12.5708 25.8296 12.583 29.2268C12.0791 29.4462 11.5549 29.5478 11.0144 29.5316C10.795 28.3491 10.7909 27.1381 10.6324 25.9515C10.2179 25.984 9.38894 26.0531 8.97851 26.0856C8.95413 27.2681 8.95413 28.4507 8.95413 29.6372C8.3649 29.6372 7.7838 29.6454 7.2027 29.6576C7.2027 28.8489 7.22709 28.0402 7.16207 27.2397C6.81666 26.5245 6.12584 27.0446 5.58944 27.1462C5.35781 28.2434 5.30092 29.365 5.32936 30.4865C4.74826 30.4825 4.17122 30.4825 3.59824 30.4865C3.59824 29.8526 3.59825 29.2227 3.60231 28.5929C3.08216 28.8408 1.88745 28.5279 1.92402 29.4015C1.82649 32.3355 1.82243 35.2898 1.92402 38.2278C2.64329 39.7964 3.97615 41.1739 3.66325 43.0514C3.09028 43.0595 2.52543 43.0676 1.96058 43.0838C1.99715 41.7347 1.18849 40.666 0.538304 39.5688C-0.20128 38.3375 0.0506709 36.8583 0.0100344 35.497C0.0669255 33.3026 -0.0874961 31.1042 0.0831771 28.918C0.538306 27.2925 2.28161 26.8577 3.76484 26.7927C4.4516 25.411 5.93485 25.1185 7.33681 25.025C8.38929 24.4114 9.55148 24.1391 10.7746 24.2407C10.864 22.4446 10.6893 20.6322 10.9291 18.8523Z"
                                                fill="#014086"></path>
                                            <path
                                                d="M29.6256 8.56308C31.763 7.20582 34.9977 8.88411 34.9693 11.4523C35.3553 14.1628 31.9906 16.2759 29.6865 14.8536C27.2808 13.667 27.2239 9.78624 29.6256 8.56308ZM30.3977 10.026C29.7393 10.8184 29.2029 12.0456 30.0929 12.8949C31.2591 14.3091 33.807 12.8868 33.1243 11.1151C32.7505 9.88376 31.4339 9.93253 30.3977 10.026Z"
                                                fill="#F98537"></path>
                                            <path
                                                d="M20.9946 16.4632C23.1727 15.3985 26.0742 17.1703 26.0092 19.6288C26.3058 22.3595 22.7745 24.3873 20.5436 22.7943C18.1216 21.4777 18.4183 17.4384 20.9946 16.4632ZM20.5557 19.1371C20.7142 19.836 20.6289 20.7544 21.34 21.1851C22.0999 21.8638 23.128 21.4249 23.8879 20.986C24.0302 20.5024 24.1765 20.0229 24.3349 19.5515C24.0058 18.6901 23.319 18.1252 22.5063 17.7514C21.7667 18.0846 21.1003 18.5397 20.5557 19.1371Z"
                                                fill="#F98537"></path>
                                        </svg>
                                        <div class="card-body">
                                            <span class="helpful-tool-text">MAKE PAYMENT</span>
                                        </div>
                                    </div>
                                </a>
                            </div>
                            <div class="col-6 col-md-4 col-lg-3 col-xl-2">
                                <a href="your-link-here">
                                    <div class="card helpful-tool-box">
                                        <svg class="tool-icon" fill="none" height="44" viewBox="0 0 28 44" width="28"
                                            xmlns="http://www.w3.org/2000/svg">
                                            <path
                                                d="M13.3031 0.0341171C14.806 -0.118999 16.3718 0.241918 17.5958 1.14421C19.2974 2.32175 20.3209 4.39976 20.2197 6.46683C20.155 7.22057 19.9336 7.94878 19.6829 8.65968C18.9711 10.601 18.0132 12.4384 17.0289 14.253C16.267 15.6301 15.4813 16.9963 14.6401 18.327C14.4387 18.6514 13.9957 18.7417 13.6585 18.5922C13.4097 18.4683 13.2821 18.2085 13.1427 17.9834C12.1 16.2909 11.1157 14.5629 10.1961 12.8011C9.32568 11.0959 8.4644 9.3642 7.96039 7.50949C7.58945 6.18065 7.80363 4.73425 8.4006 3.50476C9.30016 1.61359 11.2169 0.247387 13.3031 0.0341171ZM10.1797 3.55033C9.44781 4.59298 9.11879 5.97194 9.49793 7.20872C9.90169 8.65604 10.5488 10.0204 11.2132 11.362C12.0727 13.0745 13.0187 14.7424 14.0003 16.3884C15.4686 13.9067 16.8995 11.3884 17.9932 8.71619C18.3559 7.73461 18.7925 6.70471 18.6275 5.63745C18.4644 4.28401 17.6696 3.02171 16.5167 2.29441C15.7739 1.80954 14.8862 1.54705 13.9985 1.56255C12.5001 1.53429 11.0236 2.31628 10.1797 3.55033Z"
                                                fill="#EB7824"></path>
                                            <path
                                                d="M13.3393 3.17445C14.1568 3.01039 15.0427 3.15713 15.7335 3.63471C16.6614 4.23624 17.2027 5.37094 17.1061 6.46919C17.015 7.6367 16.2211 8.72583 15.1138 9.12594C14.1741 9.506 13.054 9.36109 12.2283 8.77961C11.5629 8.33757 11.1109 7.61027 10.9459 6.83466C10.7737 6.01895 10.9596 5.13671 11.4363 4.45406C11.871 3.80058 12.5773 3.34579 13.3393 3.17445ZM13.6008 4.71655C12.9556 4.89063 12.4406 5.50765 12.4607 6.18756C12.4014 6.99507 13.1069 7.73878 13.9043 7.77432C14.7684 7.84997 15.6032 7.06798 15.5394 6.19212C15.5795 5.21782 14.525 4.44039 13.6008 4.71655Z"
                                                fill="#EB7824"></path>
                                            <path
                                                d="M6.22214 20.9331C6.24219 20.5066 6.65597 20.1912 7.07066 20.2094C11.6915 20.2067 16.3133 20.2058 20.9341 20.2094C21.3461 20.1976 21.7872 20.5138 21.7744 20.9541C21.789 21.7397 21.7744 22.5262 21.7808 23.3128C22.6202 23.3173 23.4605 23.3028 24.3008 23.3383C25.1184 23.2973 25.9377 23.3173 26.7562 23.311C26.9904 23.3091 27.2274 23.3164 27.457 23.372C27.7906 23.4577 28.0221 23.804 27.9975 24.1449C27.9966 29.0975 27.9975 34.0492 27.9975 39.0018C27.9857 40.3452 28.0203 41.6895 27.9793 43.0329C27.8407 43.2817 27.6229 43.5406 27.3112 43.5342C26.8482 43.6272 26.4171 43.1942 26.4399 42.7422C26.4363 36.7916 26.4436 30.841 26.4363 24.8913C24.6289 24.8868 22.8207 24.895 21.0143 24.8877C20.6069 24.9023 20.2159 24.5623 20.2268 24.1449C20.2232 23.3666 20.2177 22.5873 20.2323 21.8099C19.5852 21.7333 18.9217 21.7625 18.2682 21.778C17.5391 21.7324 16.81 21.7944 16.0808 21.7798C14.7803 21.7561 13.4815 21.7916 12.1809 21.7561C11.6332 21.7479 11.0863 21.8208 10.5395 21.7716C9.87598 21.7278 9.21065 21.8135 8.54715 21.7661C8.28739 21.7506 8.02855 21.7825 7.76971 21.8017C7.77063 22.5827 7.77336 23.3638 7.76971 24.1449C7.78065 24.5623 7.39512 24.9023 6.98681 24.8877C5.17949 24.895 3.37126 24.8868 1.56302 24.8913C1.55665 30.8419 1.56394 36.7925 1.56029 42.744C1.5767 43.155 1.21487 43.5816 0.783769 43.5387C0.436523 43.5779 0.167657 43.3155 0.0200088 43.0311C-0.0200932 36.7351 0.0145429 30.4382 0.00269457 24.1413C-0.0374074 23.6719 0.40827 23.28 0.86762 23.3347C2.64942 23.3173 4.4294 23.3246 6.21212 23.3173C6.22396 22.5226 6.20209 21.7278 6.22214 20.9331Z"
                                                fill="#014086"></path>
                                            <path
                                                d="M4.66553 28.7877C4.63454 28.3356 5.07748 27.9446 5.52043 27.9975C7.55834 27.9975 9.59625 27.9957 11.6351 27.9984C12.0334 27.9638 12.4344 28.2855 12.428 28.6984C12.438 29.7629 12.4298 30.8283 12.4316 31.8928C12.4635 32.3221 12.0488 32.6912 11.6305 32.663C9.50237 32.6621 7.37332 32.6748 5.24427 32.6557C4.92163 32.5472 4.65368 32.2492 4.66553 31.8956C4.66097 30.8593 4.66097 29.823 4.66553 28.7877ZM6.21675 29.5578C6.2213 30.0737 6.21675 30.5895 6.22039 31.1054C7.77161 31.1154 9.32282 31.1072 10.874 31.1099C10.8841 30.5904 10.8804 30.0718 10.8786 29.5533C9.32465 29.5569 7.7707 29.5478 6.21675 29.5578Z"
                                                fill="#014086"></path>
                                            <path
                                                d="M15.5887 28.5694C15.6516 28.2139 16.0116 27.9715 16.3634 27.9988C18.4323 27.9979 20.5012 27.9934 22.571 28.0006C22.9811 27.987 23.3612 28.3734 23.3348 28.7863C23.3384 29.8216 23.3393 30.8579 23.3348 31.8942C23.3475 32.2487 23.0787 32.5477 22.7551 32.6561C20.627 32.6753 18.497 32.6625 16.368 32.6634C15.9824 32.6871 15.5851 32.3736 15.5714 31.9771C15.5231 31.3428 15.5541 30.7066 15.5386 30.0723C15.5732 29.5719 15.4839 29.0633 15.5887 28.5694ZM17.119 29.5582C17.1162 30.075 17.1071 30.5927 17.1226 31.1104C18.6747 31.1067 20.2269 31.1158 21.7799 31.1058C21.7826 30.5909 21.7799 30.0768 21.7826 29.5628C20.2278 29.5537 18.6729 29.5628 17.119 29.5582Z"
                                                fill="#014086"></path>
                                            <path
                                                d="M5.1611 35.8237C5.30328 35.7545 5.46643 35.7754 5.61954 35.769C7.62282 35.7736 9.62701 35.77 11.6312 35.7709C12.045 35.7417 12.4633 36.1063 12.4314 36.5346C12.4287 37.6028 12.4396 38.6719 12.4269 39.741C12.4287 40.152 12.0258 40.4674 11.6294 40.4355C9.56321 40.4327 7.49796 40.4373 5.43179 40.4336C5.01255 40.4555 4.63796 40.0554 4.6653 39.6407C4.66165 38.6063 4.65983 37.5727 4.66712 36.5383C4.66074 36.2275 4.86399 35.9222 5.1611 35.8237ZM6.21925 37.3266C6.22016 37.8425 6.21834 38.3584 6.21834 38.8751C7.77138 38.887 9.32533 38.8788 10.8784 38.8788C10.8793 38.3602 10.8866 37.8425 10.8729 37.3248C9.32168 37.3303 7.77047 37.3276 6.21925 37.3266Z"
                                                fill="#014086"></path>
                                            <path
                                                d="M15.9485 35.8742C16.098 35.7694 16.283 35.7676 16.458 35.7694C18.495 35.7749 20.5311 35.7676 22.5681 35.773C22.9773 35.7612 23.3492 36.1267 23.3328 36.5395C23.3401 37.5721 23.3373 38.6057 23.3346 39.6392C23.3619 40.0539 22.9892 40.4549 22.569 40.434C20.5001 40.4376 18.4312 40.4331 16.3623 40.4358C15.9895 40.4604 15.6022 40.1824 15.5794 39.7951C15.5101 38.716 15.5512 37.6341 15.5603 36.5532C15.5502 36.2734 15.7025 36.0063 15.9485 35.8742ZM17.1188 37.3252C17.1133 37.8428 17.1142 38.3605 17.1151 38.8791C18.6709 38.8791 20.2258 38.8873 21.7815 38.8755C21.7806 38.3587 21.7797 37.8428 21.7806 37.327C20.2267 37.3279 18.6727 37.3306 17.1188 37.3252Z"
                                                fill="#014086"></path>
                                        </svg>
                                        <div class="card-body">
                                            <span class="helpful-tool-text">RESOURCES</span>
                                        </div>
                                    </div>
                                </a>
                            </div>
                            <div class="col-6 col-md-4 col-lg-3 col-xl-2">
                                <a href="your-link-here">
                                    <div class="card helpful-tool-box">
                                        <svg class="tool-icon" fill="none" height="37" viewBox="0 0 37 37" width="37"
                                            xmlns="http://www.w3.org/2000/svg">
                                            <path
                                                d="M27.1719 9.39453C29.7619 9.39453 31.8691 7.28725 31.8691 4.69727C31.8691 2.10728 29.7619 0 27.1719 0C24.5819 0 22.4746 2.10728 22.4746 4.69727C22.4746 7.28725 24.5819 9.39453 27.1719 9.39453ZM27.1719 2.16797C28.5667 2.16797 29.7012 3.30248 29.7012 4.69727C29.7012 6.09205 28.5667 7.22656 27.1719 7.22656C25.7771 7.22656 24.6426 6.09205 24.6426 4.69727C24.6426 3.30248 25.7771 2.16797 27.1719 2.16797Z"
                                                fill="#EB7824"></path>
                                            <path
                                                d="M31.5078 11.5625H22.6155C20.6386 7.70476 16.6205 5.05859 11.9961 5.05859C5.42133 5.05859 0.0722656 10.4077 0.0722656 16.9824C0.0722656 23.5572 5.42133 28.9062 11.9961 28.9062C16.0246 28.9062 19.5922 26.8978 21.752 23.8302V37H32.5918V26.552C32.9311 26.6722 33.2958 26.7383 33.6758 26.7383C35.4689 26.7383 36.9277 25.2794 36.9277 23.4863V16.9824C36.9277 13.9938 34.4964 11.5625 31.5078 11.5625ZM18.0819 9.36348L14.9827 12.4627C14.1257 11.8945 13.0993 11.5625 11.9961 11.5625C10.8929 11.5625 9.86652 11.8945 9.00949 12.4627L5.90997 9.36348C7.5797 8.02713 9.69601 7.22656 11.9961 7.22656C14.2962 7.22656 16.4125 8.02713 18.0819 9.36348ZM8.74414 16.9824C8.74414 15.1893 10.203 13.7305 11.9961 13.7305C13.7892 13.7305 15.248 15.1893 15.248 16.9824C15.248 18.7755 13.7892 20.2344 11.9961 20.2344C10.203 20.2344 8.74414 18.7755 8.74414 16.9824ZM4.37715 10.8966L7.47639 13.9958C6.90814 14.8528 6.57617 15.8792 6.57617 16.9824C6.57617 18.0856 6.90814 19.112 7.47639 19.969L4.37715 23.0683C3.0408 21.3988 2.24023 19.2825 2.24023 16.9824C2.24023 14.6823 3.0408 12.566 4.37715 10.8966ZM5.91026 24.6014L9.00949 21.5021C9.86652 22.0704 10.8929 22.4023 11.9961 22.4023C13.0993 22.4023 14.1257 22.0704 14.9827 21.5021L18.0822 24.6014C16.4125 25.9377 14.2962 26.7383 11.9961 26.7383C9.69601 26.7383 7.5797 25.9377 5.91026 24.6014ZM19.615 23.0683L16.5158 19.969C17.084 19.112 17.416 18.0856 17.416 16.9824C17.416 15.8792 17.084 14.8528 16.5158 13.9958L19.615 10.8966C20.9514 12.566 21.752 14.6823 21.752 16.9824C21.752 19.2825 20.9514 21.3988 19.615 23.0683ZM34.7598 23.4863C34.7598 24.0839 34.2734 24.5703 33.6758 24.5703C33.0782 24.5703 32.5918 24.0839 32.5918 23.4863V16.5488H30.4238V34.832H28.2559V23.4863H26.0879V34.832H23.9199V16.9824C23.9199 15.8555 23.7627 14.7645 23.4691 13.7305H31.5078C33.3009 13.7305 34.7598 15.1893 34.7598 16.9824V23.4863Z"
                                                fill="#014086"></path>
                                        </svg>
                                        <div class="card-body">
                                            <span class="helpful-tool-text">HELP</span>
                                        </div>
                                    </div>
                                </a>
                            </div>
                            <div class="col-6 col-md-4 col-lg-3 col-xl-2">
                                <a href="your-link-here">
                                    <div class="card helpful-tool-box">
                                        <svg class="tool-icon" fill="none" height="32" viewBox="0 0 32 32" width="32"
                                            xmlns="http://www.w3.org/2000/svg">
                                            <g clip-path="url(#clip0)">
                                                <path
                                                    d="M27.4548 4.54517C24.5237 1.61401 20.6274 0 16.4819 0C16.4817 0 16.4807 0 16.4805 0C14.4302 0.000244141 12.4321 0.397217 10.5422 1.18018C8.6521 1.96313 6.95874 3.09521 5.50879 4.54517C2.57788 7.47607 0.963871 11.373 0.963871 15.5181C0.963871 17.99 1.56031 20.4465 2.69043 22.6353L0.0820349 30.0869C-0.101803 30.6125 0.028324 31.1838 0.422367 31.5776C0.698002 31.8535 1.06079 32 1.43384 32C1.59375 32 1.75537 31.9731 1.91309 31.918L9.36475 29.3098C11.5535 30.4399 14.01 31.0364 16.4819 31.0364C20.627 31.0364 24.5237 29.4221 27.4548 26.4912C30.3857 23.5603 32 19.6633 32 15.5183C32 11.373 30.386 7.47607 27.4548 4.54517ZM26.1277 25.1641C23.5513 27.7407 20.1255 29.1594 16.4819 29.1594C14.2529 29.1594 12.0386 28.6082 10.0781 27.5647C9.72266 27.3757 9.30249 27.3433 8.9253 27.4753L2.15528 29.8447L4.52491 23.0747C4.65699 22.697 4.62427 22.2769 4.43531 21.9216C3.39209 19.9617 2.84058 17.7473 2.84058 15.5181C2.84058 11.8745 4.25953 8.44873 6.83594 5.87231C9.41211 3.29614 12.8374 1.8772 16.4807 1.87671H16.4819C20.1257 1.87671 23.5513 3.29565 26.1277 5.87231C28.7043 8.44873 30.1233 11.8743 30.1233 15.5181C30.1233 19.1619 28.7043 22.5876 26.1277 25.1641Z"
                                                    fill="#014086"></path>
                                                <path
                                                    d="M22.249 16.9041C21.5352 16.1902 20.3735 16.1902 19.6597 16.9041L18.8789 17.6848C16.9402 16.6284 15.3713 15.0596 14.3147 13.1208L15.0955 12.3401C15.8096 11.6262 15.8096 10.4646 15.0955 9.75073L12.9915 7.64673C12.2776 6.93286 11.116 6.93286 10.4021 7.64673L8.719 9.32983C7.75489 10.2939 7.70679 11.9514 8.5835 13.9971C9.34473 15.7732 10.7378 17.7253 12.5061 19.4937C14.2744 21.262 16.2266 22.655 18.0027 23.4163C18.9746 23.8328 19.8587 24.0405 20.6226 24.0405C21.4666 24.0405 22.1638 23.7869 22.6699 23.2808L24.353 21.5974V21.5977C24.699 21.2517 24.8894 20.792 24.8894 20.303C24.8894 19.8137 24.699 19.354 24.353 19.0083L22.249 16.9041ZM21.3428 21.9536C21.0676 22.2288 20.2214 22.3252 18.7422 21.6914C17.1802 21.022 15.4368 19.77 13.8333 18.1665C12.2297 16.563 10.978 14.8198 10.3086 13.2578C9.67457 11.7786 9.771 10.9321 10.0461 10.657L11.697 9.0061L13.7361 11.0454L12.7588 12.0229C12.3169 12.4648 12.2102 13.135 12.4937 13.6907C13.7786 16.2102 15.7896 18.2212 18.3091 19.5061C18.865 19.7896 19.5352 19.6831 19.9771 19.241L20.9544 18.2637L22.9937 20.303L21.3428 21.9536Z"
                                                    fill="#F98537"></path>
                                            </g>
                                            <defs>
                                                <clipPath id="clip0">
                                                    <rect fill="white" height="32" width="32"></rect>
                                                </clipPath>
                                            </defs>
                                        </svg>
                                        <div class="card-body">
                                            <span class="helpful-tool-text">CALL</span>
                                        </div>
                                    </div>
                                </a>
                            </div>
                            <div class="col-6 col-md-4 col-lg-3 col-xl-2">
                                <a href="your-link-here">
                                    <div class="card helpful-tool-box">
                                        <svg class="tool-icon" fill="none" height="34" viewBox="0 0 47 34" width="47"
                                            xmlns="http://www.w3.org/2000/svg">
                                            <path
                                                d="M28.0359 0.0239385C28.2662 -0.0196115 28.5249 -0.0133157 28.7243 0.124155C28.9604 0.274744 29.1147 0.548637 29.1058 0.830924C29.1047 1.89869 29.1079 2.96697 29.1042 4.03526C29.1089 4.45502 28.7421 4.81496 28.3303 4.84015C27.9981 4.86481 27.6565 4.67749 27.5154 4.37316C27.4367 4.22048 27.4183 4.0468 27.4215 3.87785C27.4251 2.86203 27.4178 1.84622 27.4246 0.830924C27.4293 0.468882 27.6749 0.108415 28.0359 0.0239385Z"
                                                fill="#EB7824"></path>
                                            <path
                                                d="M23.0981 2.32218C23.4654 2.21042 23.8915 2.38567 24.073 2.72515C24.5977 3.54683 25.1193 4.3706 25.6456 5.19176C25.8728 5.54278 25.7809 6.04492 25.4488 6.29625C25.1434 6.5502 24.6576 6.53079 24.3663 6.26477C24.2268 6.13727 24.1407 5.96621 24.0389 5.80985C23.5704 5.07003 23.0955 4.3344 22.6264 3.59458C22.4979 3.38994 22.4454 3.13127 22.5241 2.8983C22.5913 2.61864 22.8279 2.40456 23.0981 2.32218Z"
                                                fill="#EB7824"></path>
                                            <path
                                                d="M32.9615 2.5171C33.3655 2.43105 33.8178 2.69864 33.9238 3.10109C34.0103 3.35084 33.9453 3.62789 33.8026 3.84301C33.2815 4.6542 32.7621 5.46643 32.2479 6.28181C32.039 6.63283 31.5637 6.79392 31.1896 6.62234C30.8564 6.48539 30.6475 6.11968 30.678 5.76393C30.7163 5.468 30.9193 5.23661 31.0689 4.99053C31.4944 4.31472 31.9299 3.6452 32.3554 2.96939C32.4892 2.74849 32.6965 2.55435 32.9615 2.5171Z"
                                                fill="#EB7824"></path>
                                            <path
                                                d="M12.7875 9.01085C14.0604 8.60631 15.3968 8.39223 16.7332 8.40063C26.4931 8.40115 36.2531 8.4001 46.013 8.40115C46.4437 8.38804 46.8436 8.70233 46.9653 9.1095C47.023 9.32672 46.9973 9.55549 46.97 9.77534C46.7407 11.3232 46.5099 12.8716 46.2832 14.42C46.2528 14.6881 46.1316 14.9494 45.9243 15.1257C45.7076 15.3062 45.4269 15.3686 45.1719 15.473C39.7916 17.5078 34.4082 19.5332 29.0311 21.5753C28.9755 22.2574 28.9115 22.9411 28.7604 23.6101C28.3128 25.7241 27.298 27.7116 25.8656 29.3277C24.6336 30.7171 23.0968 31.8379 21.3883 32.5677C17.8335 34.1182 13.5593 33.87 10.2081 31.9176C8.4031 30.8708 6.85839 29.3734 5.76859 27.5931C5.21871 26.7121 4.80892 25.7529 4.47573 24.7723C3.74325 24.9229 2.97457 24.8085 2.29141 24.5157C1.4477 24.139 0.741454 23.4558 0.353702 22.6152C0.0136972 21.9148 -0.0618597 21.1125 0.0451788 20.348C0.212033 19.3065 0.837474 18.3547 1.71634 17.7744C2.52071 17.2324 3.53967 17.0162 4.49357 17.1972C4.77481 16.354 5.12636 15.5318 5.57865 14.7652C7.15117 12.0357 9.78516 9.95216 12.7875 9.01085ZM11.6557 11.2833C9.52491 12.3427 7.73621 14.0994 6.68891 16.2407C5.72452 18.1616 5.38923 20.3795 5.68621 22.504C5.94804 24.448 6.75922 26.3128 7.99541 27.8355C9.18018 29.2999 10.7396 30.4679 12.4978 31.151C14.5646 31.9669 16.8854 32.107 19.0424 31.585C21.0205 31.0954 22.8549 30.0397 24.2674 28.5711C25.7848 27.0138 26.8258 24.9937 27.1905 22.8487C27.2985 22.25 27.3442 21.6424 27.3557 21.0348C27.3694 20.6235 27.6774 20.2614 28.0615 20.1339C33.5446 18.063 39.0277 15.9925 44.5102 13.9205C44.5931 13.89 44.6871 13.8449 44.6802 13.7405C44.8544 12.5211 45.0465 11.3038 45.216 10.0839C40.6763 10.0812 36.1366 10.0807 31.5974 10.0839C31.5984 10.8489 31.5974 11.6139 31.5985 12.3789C31.5974 12.6119 31.6137 12.8506 31.5402 13.0757C31.4138 13.4771 31.0097 13.7767 30.5863 13.7683C29.029 13.7651 27.4712 13.7714 25.9139 13.7651C25.4039 13.7636 24.9526 13.3087 24.9495 12.7997C24.9442 11.8946 24.9484 10.989 24.9484 10.0839C22.2279 10.0797 19.5068 10.0828 16.7862 10.0823C15.0133 10.0707 13.2403 10.4889 11.6557 11.2833ZM26.6385 10.0812C26.6175 10.7476 26.6311 11.4145 26.6322 12.0814C27.7241 12.0872 28.8165 12.0882 29.9089 12.0803C29.9058 11.4145 29.9226 10.7476 29.9005 10.0818C28.8134 10.0818 27.7257 10.0828 26.6385 10.0812ZM2.02172 19.8118C1.67332 20.3412 1.59409 21.027 1.77563 21.6299C2.0553 22.5869 3.08004 23.2853 4.07486 23.1279C3.91536 22.0365 3.83508 20.9262 3.95418 19.8265C3.98042 19.497 4.05073 19.1737 4.07801 18.8448C3.28099 18.7131 2.4525 19.1428 2.02172 19.8118Z"
                                                fill="#014086"></path>
                                            <path
                                                d="M15.9142 13.8684C17.6919 13.7215 19.5152 14.2772 20.9057 15.3958C21.7216 16.0543 22.4084 16.8807 22.8696 17.8246C23.7349 19.5603 23.8435 21.6534 23.1603 23.4683C22.527 25.1846 21.2037 26.6343 19.552 27.4209C17.9301 28.21 16.0019 28.338 14.2871 27.7808C12.5368 27.2314 11.0356 25.9622 10.1693 24.3487C9.23797 22.6199 9.06797 20.5006 9.72175 18.6484C10.3199 16.8854 11.6537 15.3984 13.3196 14.5768C14.1292 14.1801 15.0144 13.9319 15.9142 13.8684ZM16.0711 15.5454C15.2919 15.5994 14.5259 15.8282 13.8422 16.2065C12.1327 17.1305 10.9847 19.0315 11.0225 20.9823C11.0031 21.9755 11.2922 22.9651 11.8074 23.812C12.7571 25.3997 14.5631 26.446 16.419 26.4313C17.5161 26.458 18.6112 26.1149 19.5184 25.5015C21.0138 24.5062 21.9598 22.7301 21.9157 20.9298C21.9268 19.1128 20.9241 17.3456 19.3904 16.3833C18.4129 15.7542 17.2302 15.4604 16.0711 15.5454Z"
                                                fill="#EB7824"></path>
                                        </svg>
                                        <div class="card-body">
                                            <span class="helpful-tool-text">FAQS</span>
                                        </div>
                                    </div>
                                </a>
                            </div>

                            <div class="col-6 col-md-4 col-lg-3 col-xl-2">
                                <a href="your-link-here">
                                    <div class="card helpful-tool-box">
                                        <svg class="tool-icon" fill="none" height="36" viewBox="0 0 33 36" width="33"
                                            xmlns="http://www.w3.org/2000/svg">
                                            <path
                                                d="M5.24871 3.21137C5.68992 1.71716 6.94387 0.441048 8.51629 0.122022C10.2977 -0.294664 12.1388 0.502898 13.426 1.69762C14.8358 2.94442 15.6718 4.64697 16.4812 6.29418C17.6357 4.00566 19.0157 1.55113 21.5037 0.457324C23.3448 -0.460688 25.8162 0.0243658 27.0038 1.72366C28.3971 3.52388 28.1251 5.97191 27.4218 7.98698C26.7716 7.98372 26.1214 7.98372 25.4712 7.98047C25.8395 6.39511 26.5295 4.61117 25.6106 3.07464C25.0201 1.88969 23.368 1.58042 22.2501 2.21522C19.9611 3.30251 18.8797 5.73426 17.9774 7.92186C17.012 7.98697 16.0433 7.99999 15.078 7.98372C14.0728 5.68543 12.9582 2.98349 10.374 2.03943C8.99067 1.42743 7.36518 2.47565 7.07657 3.85918C6.67849 5.24922 7.22253 6.65554 7.55095 8C6.87089 7.9707 6.19084 7.92838 5.51078 7.87304C5.07289 6.36906 4.75774 4.74139 5.24871 3.21137Z"
                                                fill="#F98537"></path>
                                            <path
                                                d="M1.35356 10.164C2.39954 9.91322 3.48499 10.0303 4.5507 10.0102C13.1093 10.0269 21.6679 10.0135 30.2265 10.0135C30.9501 10.0236 31.7691 10.0403 32.3119 10.6088C32.9796 11.2408 32.9763 12.2273 32.9895 13.0834C32.9796 14.538 33.0421 15.996 32.9434 17.4473C32.9105 18.3435 32.1145 18.8953 31.6935 19.6109C31.5323 20.0858 31.5817 20.6007 31.5619 21.0957C31.5882 25.0115 31.5685 28.924 31.5817 32.8399C31.5521 33.7428 31.5981 34.8496 30.7955 35.4516C30.2857 35.9398 29.5686 35.9933 28.9075 35.9967C20.6745 35.99 12.4416 35.9833 4.20533 36C3.46196 35.9833 2.5936 35.9699 2.05746 35.3546C1.38645 34.6992 1.42921 33.696 1.41606 32.8299C1.4325 28.6933 1.42592 24.5567 1.4325 20.4202C1.6167 19.1561 -0.0377875 18.6746 0.0411542 17.4273C-0.0180521 15.6549 -0.00818504 13.8759 0.0378643 12.1002C-0.00160656 11.2408 0.600324 10.4851 1.35356 10.164ZM1.98181 11.9397C1.84695 13.8224 1.8305 15.7151 1.97523 17.5978C5.51774 17.6179 9.06025 17.6112 12.6028 17.5978C12.6389 15.7118 12.6291 13.8257 12.6028 11.9397C9.06354 11.933 5.52103 11.9364 1.98181 11.9397ZM14.55 11.9397C14.5105 13.8291 14.5171 15.7185 14.5599 17.6078C15.8295 17.6179 17.0991 17.6179 18.3688 17.6012C18.5135 15.7118 18.5168 13.8157 18.3655 11.9297C17.0926 11.9263 15.8229 11.923 14.55 11.9397ZM20.4015 11.9196C20.339 13.8124 20.3292 15.7118 20.4015 17.6045C23.9408 17.5744 27.4833 17.6747 31.0225 17.5543C31.1113 15.6951 31.0948 13.8291 31.0225 11.9665C27.4833 11.8962 23.9408 11.9698 20.4015 11.9196ZM3.35342 19.5641C3.33368 24.3895 3.31395 29.215 3.36328 34.0437C6.44201 34.134 9.52732 34.0972 12.606 34.0672C12.6324 29.235 12.6225 24.4029 12.6159 19.5708C9.52732 19.5206 6.44201 19.5307 3.35342 19.5641ZM14.5368 19.5641C14.527 24.3862 14.5237 29.2116 14.5401 34.0337C15.8262 34.0571 17.1123 34.0571 18.4017 34.0337C18.4938 29.2116 18.5004 24.3828 18.3951 19.5607C17.109 19.5307 15.8229 19.5307 14.5368 19.5641ZM20.3851 19.5474C20.3456 24.3895 20.3423 29.2317 20.3884 34.0738C23.4507 34.1039 26.5195 34.1273 29.5818 34.0504C29.7298 29.2217 29.7002 24.3795 29.5982 19.5507C26.5261 19.534 23.4572 19.544 20.3851 19.5474Z"
                                                fill="#014086"></path>
                                        </svg>
                                        <div class="card-body">
                                            <span class="helpful-tool-text">EVENTS</span>
                                        </div>
                                    </div>
                                </a>
                            </div>
                            <!-- Add more helpful tools as needed -->
                        </div>
                        <!-- HELPFUL TOOLS ROW ENDS-->
                    </div>
                </section>

                <!-- <div class="col-lg-4">
                <div class="card">
                    <div class="card-body">
                        <div class="card-widgets">
                            <a href="javascript:;" data-bs-toggle="reload"><i class="ri-refresh-line"></i></a>
                            <a data-bs-toggle="collapse" href="#virtual-account-details" role="button" aria-expanded="false" aria-controls="virtual-account-details"><i class="ri-subtract-line"></i></a>
                            <a href="#" data-bs-toggle="remove"><i class="ri-close-line"></i></a>
                        </div>
                        <h5 class="card-header-title mb-0 text-center"><?php echo $_SESSION['pro']; ?> Virtual Account Details</h5>
                        <div id="virtual-account-details" class="collapse pt-3 show">
                            <div class="row">
                                <div class="col-12 text-center">
                                    <p class="text-muted mt-3 mb-2">Account Number:</p>
                                    <h4 id="account-number" class="account-number"><?php echo $accountNumber; ?></h4>
                                    <p class="text-muted mt-3 mb-2">Bank Name:</p>
                                    <h4 id="bank-name" class="account-number"><?php echo $bankName; ?></h4>
                                    <p class="text-muted mt-3 mb-2">Balance:</p>
                                    <h4 id="balance" class="balance"><?php echo $balance; ?></h4>
                                </div>
                            </div>
                        </div>
                    </div> 
                </div> 
            </div> 
        </div> 
    </div>  -->



    <?php
include 'conn.php';

// Set the initial limit and page for the first load
$limit = 4;
$page = isset($_GET['page']) ? (int)$_GET['page'] : 1; // Get the page number from the URL parameter
$offset = ($page - 1) * $limit;  // Calculate the offset

// Fetch the first 4 records for the initial page
$stmt = $conn->prepare("SELECT * FROM navbars WHERE status = 'active' ORDER BY `order` ASC LIMIT :limit OFFSET :offset");
$stmt->bindParam(':limit', $limit, PDO::PARAM_INT);
$stmt->bindParam(':offset', $offset, PDO::PARAM_INT);
$stmt->execute();
$menuItems = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>

<!-- Bootstrap Cards -->
<div class="container mt-3">
    <div class="col-12">
        <div class="section-title">
            <h3>Dashboard Quick <span class="alternate">Links</span></h3>
            <p>Navigate through your dashboard with the following quick links</p>
        </div>
    </div>
    
    <!-- Bootstrap Cards -->
    <div class="row" id="cards-container">
        <?php foreach ($menuItems as $item): ?>
            <div class="col-sm-6 col-lg-3 mb-4">
                <div class="card">
                    <?php
                    $imageSrc = !empty($item['image']) ? htmlspecialchars($item['image']) : './dist/img/bg-login.jpg';
                    ?>
                    <img src=".<?php echo $imageSrc; ?>" class="card-img-top" alt="Card Image">
                    <div class="card-body">
                        <h5 class="card-title"><?php echo htmlspecialchars($item['name']); ?></h5>
                        <a href="<?php echo htmlspecialchars($item['link']); ?>" class="btn btn-primary mt-2 stretched-link" onclick="createRipple(event)">Explore</a>
                        <span class="ripple"></span>
                    </div>
                </div>
            </div>
        <?php endforeach; ?>
    </div>

    <!-- Load More Button -->
    <div class="text-center">
        <button id="loadMoreBtn" class="btn btn-primary" onclick="loadMoreCards(<?php echo $page + 1; ?>)">Load More</button>
    </div>
</div>

<!-- Add JavaScript for AJAX -->
<script>
    function loadMoreCards(page) {
        const loadMoreBtn = document.getElementById('loadMoreBtn');
        const container = document.getElementById('cards-container');

        const xhr = new XMLHttpRequest();
        xhr.open('GET', 'load_more.php?page=' + page, true);
        xhr.onreadystatechange = function () {
            if (xhr.readyState === 4 && xhr.status === 200) {
                const response = xhr.responseText;
                if (response.trim() !== '') {
                    container.innerHTML += response; // Append new cards
                    loadMoreBtn.setAttribute('onclick', 'loadMoreCards(' + (page + 1) + ')'); // Update button to load next set
                } else {
                    loadMoreBtn.style.display = 'none'; // Hide the button if no more cards
                }
            }
        };
        xhr.send();
    }
</script>




                <script>
                    function createRipple(event) {
                        const button = event.currentTarget;
                        const ripple = document.createElement("span");
                        const rect = button.getBoundingClientRect();
                        const size = Math.max(rect.width, rect.height);
                        ripple.style.width = ripple.style.height = `${size}px`;
                        ripple.style.left = `${event.clientX - rect.left - size / 2}px`;
                        ripple.style.top = `${event.clientY - rect.top - size / 2}px`;
                        ripple.classList.add("ripple");

                        // Remove any existing ripple before adding a new one
                        const previousRipple = button.querySelector(".ripple");
                        if (previousRipple) {
                            button.removeChild(previousRipple);
                        }

                        button.appendChild(ripple);

                        // Optional: Remove the ripple after the animation is done
                        ripple.addEventListener('animationend', () => {
                            ripple.remove();
                        });
                    }
                </script>

                <section>
                    <?php
                    include 'conn.php';

                    // Fetch images from the analysis table
                    $stmt = $conn->query("SELECT * FROM analysis");
                    $analysisItems = $stmt->fetchAll(PDO::FETCH_ASSOC);

                    // Define the default image path
                    $defaultImage = './dist/img/ticket2.svg'; // Path to your default image
                    ?>


                    <div class="container mt-3">
                        <?php if (!empty($analysisItems)): ?>
                            <div class="col-12">
                                <div class="section-title">
                                    <h3>Registration<span class="alternate">Analysis</span></h3>
                                    <p>Stay up to date with recent developments and activities of the National Convention
                                    </p>
                                </div>
                            </div>
                        <?php endif; ?>

                        <!-- First Section of Cards -->
                        <div class="row">
                            <?php foreach ($analysisItems as $index => $item): ?>
                                <div
                                    class="col-xl-3 col-sm-6 col-12 mb-custom <?php echo $index % 1 === 0 ? 'first-row-spacing' : ''; ?>">
                                    <div class="card bg-comman w-100">
                                        <div class="card-body">
                                            <div class="db-widgets d-flex justify-content-between align-items-center">
                                                <div class="db-info">
                                                    <h6><?php echo htmlspecialchars($item['description']); ?></h6>
                                                    <h3 class="number">30</h3>
                                                    <!-- Example number, replace with actual data if needed -->
                                                </div>
                                                <div class="db-icon">
                                                    <?php
                                                    // Check if the image path is empty or the file does not exist
                                                    $imagePath = !empty($item['image']) && file_exists($item['image']) ? htmlspecialchars($item['image']) : $defaultImage;
                                                    ?>
                                                    <img src=".<?php echo $imagePath; ?>" class="card-img-top" alt="Icon">
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                    <!-- <section class="news section">
    <div class="container">
        <div class="row">
            <div class="col-12">
                <div class="section-title">
                    <h3>DTCE <span class="alternate">Blog</span></h3>
                    <p>Stay up to date with recent developments and activities in Junior Church</p>
                </div>
            </div>
        </div>
        <div class="row">
          
            <div class="col-lg-4 col-md-6 col-sm-12 mb-4">
                <div class="card">
                    <img src="../dist/img/bg-login.jpg" class="card-img-top" alt="NatConf Announcement">
                    <div class="card-body">
                    <h5 class="card-title"><a href="#" style="text-decoration:none;">Annual General Meeting Notice</a></h5>
                        <p class="card-text"><small class="text-muted">  <li class="list-inline-item"><i class="fas fa-calendar"></i> 11 June</li> </small></p>
                        <ul class="list-inline">
                        <li class="list-inline-item"><i class="fas fa-user"></i> Admin</li>
                            <li class="list-inline-item"><i class="fas fa-heart"></i> 30k</li>
                            <li class="list-inline-item"><i class="fas fa-comments"></i> 10k</li>
                        </ul>
                    </div>
                </div>
            </div>
          
            <div class="col-lg-4 col-md-6 col-sm-12 mb-4">
                <div class="card">
                <img src="../dist/img/bg-login.jpg" class="card-img-top" alt="NatConf Announcement">
                    <div class="card-body">
                        <h5 class="card-title"><a href="#">Annual General Meeting Notice</a></h5>
                        <p class="card-text"><small class="text-muted">  <li class="list-inline-item"><i class="fas fa-calendar"></i> 20 June</li> </small></p>
                        <ul class="list-inline">
                        <li class="list-inline-item"><i class="fas fa-user"></i> Super Admin</li>
                            <li class="list-inline-item"><i class="fas fa-heart"></i> 30k</li>
                            <li class="list-inline-item"><i class="fas fa-comments"></i> 10k</li>
                        </ul>
                    </div>
                </div>
            </div>
          
            <div class="col-lg-4 col-md-6 col-sm-12 mb-4">
                <div class="card">
                <img src="../dist/img/bg-login.jpg" class="card-img-top" alt="NatConf Announcement">
                    <div class="card-body">
                    <h5 class="card-title"><a href="#">Annual General Meeting Notice</a></h5>
                        <p class="card-text"><small class="text-muted">  <li class="list-inline-item"><i class="fas fa-calendar"></i> 23 June</li> </small></p>
                        <ul class="list-inline">
                            <li class="list-inline-item"><i class="fas fa-user"></i> Registrar</li>
                            <li class="list-inline-item"><i class="fas fa-heart"></i> 30k</li>
                            <li class="list-inline-item"><i class="fas fa-comments"></i> 10k</li>
                        </ul>
                    </div>
                </div>
            </div>
        </div>
    </div>
</section> -->

                    <?php
                    // Include the database connection
                    include 'conn.php';

                    // Initialize meetings variable
                    $meetings = [];

                    // Fetch all meetings for display
                    $stmt = $conn->prepare("SELECT * FROM meetings");
                    $stmt->execute();
                    $meetings = $stmt->fetchAll(PDO::FETCH_ASSOC);
                    ?>
                    <div class="container">
                        <div class="row">
                            <div class="col-12">
                                <div class="section-title">
                                    <h3>DTCE <span class="alternate">Meetings</span></h3>
                                    <p>Stay up to date with recent meetings</p>
                                </div>
                            </div>
                        </div>

                        <div class="row">
                            <?php foreach ($meetings as $meeting): ?>
                                <?php
                                // Create the Zoom link for the current meeting
                                $zoom_link = "https://zoom.us/j/" . htmlspecialchars($meeting['meeting_id']);
                                ?>
                                <div class="col-md-3 mb-4">
                                    <div class="card shadow-lg border-0">
                                        <div class="position-relative">
                                            <a href="<?php echo $zoom_link; ?>" target="_blank">
                                                <img src=".<?php echo htmlspecialchars($meeting['meeting_image']); ?>""
                                                    alt="Meeting Image" class="card-img-top img-fluid rounded-top">
                                            </a>
                                            <div class="position-absolute top-0 start-0 m-2">
                                                <?php if (htmlspecialchars($meeting['status']) === 'active'): ?>
                                                    <a href="<?php echo $zoom_link; ?>" target="_blank" class="btn btn-primary" style="font-size: 0.8rem; padding: 5px 10px;">
                                                        Join Meeting
                                                    </a>
                                                <?php else: ?>
                                                    <span class="badge bg-danger">
                                                        FINISHED
                                                    </span>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                        <br>
                                        <div class="card-body">
                                            <h5 class="card-title text-dark font-weight-bold mb-4">
                                                <?php echo htmlspecialchars($meeting['title']); ?>
                                            </h5>
                                            <div class="d-flex justify-content-between mb-2">
                                                <div class="d-flex align-items-center">
                                                    <i class="fa fa-calendar text-primary me-3"></i>
                                                    <span class="text-muted"><?php echo htmlspecialchars(date('M d, Y', strtotime($meeting['date']))); ?></span>
                                                </div>
                                                <div class="d-flex align-items-center">
                                                    <i class="fa fa-clock text-primary me-3"></i>
                                                    <span class="text-muted"><?php echo htmlspecialchars($meeting['duration']); ?></span>
                                                </div>
                                            </div>
                                            <p class="text-muted mb-3">
                                                Starting Time:
                                                <span class="text-primary font-weight-bold">
                                                    <?php echo htmlspecialchars(date('g:i A', strtotime($meeting['start_time']))); ?>
                                                </span>
                                            </p>
                                            <p class="text-muted mb-3">
                                                Meeting ID: <span class="text-secondary font-weight-bold"><?php echo htmlspecialchars($meeting['meeting_id']); ?></span>
                                            </p>
                                            <div class="pt-3 border-top">
                                                <a href="instructor-details.html"
                                                    class="d-flex align-items-center text-muted hover:text-primary">
                                                    <img class="rounded-circle me-3"
                                                        src="<?php echo htmlspecialchars($meeting['speaker_image']); ?>"
                                                        alt="Speaker" width="50" height="50">
                                                    <div>
                                                        <span>Organizer:</span>
                                                        <h6 class="mb-0 font-weight-bold text-dark">
                                                            <?php echo htmlspecialchars($meeting['speaker_name']); ?></h6>
                                                    </div>
                                                </a>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>


                    <!-- Upcoming Events Section---->
                    <?php
                    // Include your database connection
                    include 'conn.php'; // This will replace the previous connection code

                    try {
                        // Fetch upcoming events
                        $stmt = $conn->query("SELECT * FROM upcomingevents ORDER BY event_date ASC");
                        $events = $stmt->fetchAll(PDO::FETCH_ASSOC);
                    } catch (PDOException $e) {
                        echo "Database error: " . $e->getMessage();
                        die();
                    }
                    ?>

                    <!-- For displaying events -->
                    <div class="container mt-3">
                        <div class="col-12">
                            <div class="section-title">
                                <h3>Upcoming <span class="alternate">Events</span></h3>
                                <p>Stay up to date with recent events and activities of DTCE</p>
                            </div>
                        </div>

                        <?php if (count($events) > 0): ?>
                            <?php if (count($events) > 4): ?>
                                <div id="event-carousel" class="carousel slide" data-bs-ride="carousel">
                                    <div class="carousel-inner">
                                        <?php foreach (array_chunk($events, 4) as $index => $eventChunk): ?>
                                            <div class="carousel-item <?php echo $index === 0 ? 'active' : ''; ?>">
                                                <div class="row g-4">
                                                    <?php foreach ($eventChunk as $event): ?>
                                                        <div class="col-lg-3 col-md-6">
                                                            <div class="card event-card">
                                                                <img src=".<?php echo htmlspecialchars($event['event_image']); ?>""
                                                                    class="card-img-top" alt="Event Banner">
                                                                <div class="card-body">
                                                                    <h5 class="card-title"><?php echo htmlspecialchars($event['event_name']); ?></h5>
                                                                    <p class="card-text">
                                                                        <?php echo nl2br(htmlspecialchars($event['event_details'])); ?>
                                                                    </p>
                                                                    <a href="<?php echo (strtotime($event['event_date']) < time() || $event['button_active'] == 0) ? 'javascript:void(0);' : htmlspecialchars($event['event_link']); ?>"
                                                                        class="btn btn-primary"
                                                                        <?php echo (strtotime($event['event_date']) < time() || $event['button_active'] == 0) ? 'disabled' : ''; ?>>
                                                                        <?php
                                                                        // If the event is closed, display "Event Closed", otherwise display the original button text
                                                                        echo (strtotime($event['event_date']) < time() || $event['button_active'] == 0) ? 'Event Closed' : htmlspecialchars($event['button_text']);
                                                                        ?>
                                                                    </a>


                                                                    <div class="countdown mt-3" data-event-date="<?php echo $event['event_date']; ?>"></div>
                                                                </div>
                                                            </div>
                                                        </div>
                                                    <?php endforeach; ?>
                                                </div>
                                            </div>
                                        <?php endforeach; ?>
                                    </div>

                                    <!-- Carousel Controls -->
                                    <button class="carousel-control-prev" type="button" data-bs-target="#event-carousel" data-bs-slide="prev">
                                        <span class="carousel-control-prev-icon" aria-hidden="true"></span>
                                        <span class="visually-hidden">Previous</span>
                                    </button>
                                    <button class="carousel-control-next" type="button" data-bs-target="#event-carousel" data-bs-slide="next">
                                        <span class="carousel-control-next-icon" aria-hidden="true"></span>
                                        <span class="visually-hidden">Next</span>
                                    </button>
                                </div>
                            <?php else: ?>
                                <div class="row g-4">
                                    <?php foreach ($events as $event): ?>
                                        <div class="col-lg-3 col-md-6">
                                            <div class="card event-card">
                                                <img src=".<?php echo htmlspecialchars($event['event_image']); ?>"" class="card-img-top" alt="Event Banner">
                                                <div class="card-body">
                                                    <h5 class="card-title"><?php echo htmlspecialchars($event['event_name']); ?></h5>
                                                    <p class="card-text">
                                                        <?php echo nl2br(htmlspecialchars($event['event_details'])); ?></p>
                                                    <a href="<?php echo (strtotime($event['event_date']) < time() || $event['button_active'] == 0) ? 'javascript:void(0);' : htmlspecialchars($event['event_link']); ?>"
                                                        class="btn btn-primary"
                                                        <?php echo (strtotime($event['event_date']) < time() || $event['button_active'] == 0) ? 'disabled' : ''; ?>>
                                                        <?php
                                                        // If the event is closed, display "Event Closed", otherwise display the original button text
                                                        echo (strtotime($event['event_date']) < time() || $event['button_active'] == 0) ? 'Event Closed' : htmlspecialchars($event['button_text']);
                                                        ?>
                                                    </a>


                                                    <div class="countdown mt-3" data-event-date="<?php echo $event['event_date']; ?>"></div>
                                                </div>
                                            </div>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                            <?php endif; ?>
                        <?php else: ?>
                            <p>No upcoming events at the moment.</p>
                        <?php endif; ?>
                    </div>


                    <?php
                    include 'conn.php';

                    // Fetch video details from the videos table
                    $stmt = $conn->query("SELECT * FROM videos");
                    $videoItems = $stmt->fetchAll(PDO::FETCH_ASSOC);

                    // Define default thumbnail (if needed)
                    $defaultThumbnail = 'https://img.youtube.com/vi/czB6KESJLQ4/maxresdefault.jpg'; // Path to your default thumbnail

                    // Debug: Output the paths being used
                    // var_dump($videoItems); // Uncomment for debugging
                    ?>

                    <div class="container mt-4">
                        <?php if (!empty($videoItems)): ?>
                            <div class="col-12">
                                <div class="section-title">
                                    <h3>DTCE <span class="alternate">Videos</span></h3>
                                    <p>Stay up to date with recent DTCE Videos</p>
                                </div>
                            </div>
                        <?php endif; ?>
                        <div class="row" id="videoContainer">
                            <?php foreach ($videoItems as $index => $item): ?>
                                <div class="col-md-4 mb-4">
                                    <div class="video-card" data-id="<?php echo htmlspecialchars($item['video_id']); ?>">
                                        <div class="position-relative">
                                            <?php
                                            // Generate the YouTube thumbnail URL
                                            $videoId = !empty($item['video_id']) ? htmlspecialchars($item['video_id']) : '';
                                            $thumbnailPath = $videoId ? "https://img.youtube.com/vi/$videoId/maxresdefault.jpg" : $defaultThumbnail;
                                            ?>
                                           <img src="<?php echo $thumbnailPath; ?>" class="img-fluid" alt="<?php echo htmlspecialchars($item['title']); ?>">

                                            <iframe class="video-iframe" src="" allowfullscreen></iframe>
                                        </div>
                                        <div class="video-card-body">
                                            <h5 class="video-card-title"><?php echo htmlspecialchars($item['title']); ?></h5>
                                            <p class="video-card-text"><?php echo htmlspecialchars($item['description']); ?></p>
                                        </div>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>





                </section>


        </div>

        <?php
        include 'conn.php'; // Make sure this file contains your database connection

        // Fetch the modal content from the database
        $stmt = $conn->query("SELECT message FROM modal_content ORDER BY id DESC LIMIT 1");
        $modalContent = $stmt->fetch(PDO::FETCH_ASSOC);
        $message = $modalContent['message'];
        ?>

        <!-- Modal HTML -->
        <div id="announcementModal" class="modal">
            <div class="modal-content">
                <span class="close-btn" onclick="closeModal()">&times;</span>
                <h2>🎉 Welcome to the New Convention Portal! 🎉</h2>
                <p>
                    <?php echo $message; ?>
                </p>
            </div>
        </div>
        <style>
            /* Modal Background */
            .modal {
                display: none;
                /* Hidden by default */
                position: fixed;
                /* Stay in place */
                z-index: 1;
                /* Sit on top */
                left: 0;
                top: 0;
                width: 100%;
                /* Full width */
                height: 100%;
                /* Full height */
                overflow: auto;
                /* Enable scroll if needed */
                background: rgba(0, 0, 0, 0.5);
                /* Black background with opacity */
            }

          /* Light Mode Styles (default) */
body {
    background-color: #f0f0f0;
    color: #333;
}

/* Modal Content for Light Mode */
.modal-content {
    background-color: white; /* White background for light mode */
    color: black; /* Black text in light mode */
    margin: 15% auto;
    padding: 20px;
    border-radius: 10px;
    width: 80%;
    box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1); /* Optional: Add a subtle shadow for better visibility */
}

.modal-body {
    background-color: #fff; /* Light background for modal body */
    padding: 20px; /* Padding for the content inside the modal */
    border-radius: 8px;
}

/* Close Button */
.close-btn {
    color: #000; /* Black close button in light mode */
    font-size: 28px;
    font-weight: bold;
    cursor: pointer;
}

.close-btn:hover {
    color: #ff0000; /* Red close button on hover */
}

/* Dark Mode Styles */
body.dark-mode {
    background-color: #2c2c2c; /* Dark background */
    color: #f1f1f1; /* Light text */
}

/* Modal Content for Dark Mode */
body.dark-mode .modal-content {
    background-color: black; /* Black background for dark mode */
    color: white; /* White text in dark mode */
}

body.dark-mode .modal-body {
    background-color: #333; /* Dark background for modal body in dark mode */
}

/* Dark Mode Specific Modal Styles */
body.dark-mode .close-btn {
    color: #fff; /* White close button in dark mode */
}

/* Gradient Animation for Modal Background */
@keyframes gradientAnimation {
    0% {
        background-position: 0% 0%;
    }

    50% {
        background-position: 100% 0%;
    }

    100% {
        background-position: 0% 100%;
    }
}

        </style>
        <!-- Button to Trigger Toast (For Testing) -->


        <!-- Toast Container -->
        <div class="toast-container" style="position: absolute; top: 20px; right: 20px;">
            <!-- Toast HTML -->
            <div class="toast" id="myToast" role="alert" aria-live="assertive" aria-atomic="true" data-delay="3000">
                <div class="toast-header">
                    <strong class="mr-auto">Welcome Message</strong>
                    <small class="text-muted">just now</small>
                    <button type="button" class="ml-2 mb-1 close" data-dismiss="toast" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <div class="toast-body" id="toastBody">
                    <p>Welcome back, <?php echo htmlspecialchars($_SESSION['pro'], ENT_QUOTES, 'UTF-8'); ?>! We are glad to
                        have you here.</p>
                </div>
            </div>
        </div>

        <!-- /.content-wrapper -->

        <!-- Footer -->
        <?php
        include 'conn.php'; // Ensure this file contains your database connection

        // Fetch footer content from the footer table
        $stmt = $conn->query("SELECT * FROM footer ORDER BY id DESC LIMIT 1");
        $footer = $stmt->fetch(PDO::FETCH_ASSOC);
        $copyrightMessage = $footer['copyright_message'] ?? '&copy; ' . date('Y') . ' Directorate of Teens and Children Education.';
        $eventInfo = $footer['event_info'] ?? 'CO-ORDINATOR\'S EVENT REGISTRATION PORTAL v.1.0.0';
        ?>
        <footer class="main-footer text-sm">
            <div class="text-xs" id="copyright">
                <?php echo $copyrightMessage; ?>
                <div class="float-right d-none d-sm-inline-block">
                    <b><?php echo $eventInfo; ?></b>
                </div>
            </div>
        </footer>
        <script>
            $(document).ready(function() {
                $('#videoContainer').on('click', '.video-card', function() {
                    const videoId = $(this).data('id');
                    const iframe = $(this).find('.video-iframe');

                    // Set the iframe src to the video URL
                    iframe.attr('src', `https://www.youtube.com/embed/${videoId}?autoplay=1`);

                    // Show the iframe and hide the thumbnail
                    iframe.show();
                    $(this).find('img').hide();
                });
            });
        </script>
        <!-- ./wrapper -->


        <!-- Scripts -->
        <script src="../plugins/jquery/jquery.min.js"></script>
        <script src="../plugins/bootstrap/js/bootstrap.bundle.min.js"></script>
        <script src="../plugins/intl-tel-input-17.0.0/build/js/intlTelInput.min.js"></script>
        <script src="../plugins/sweetalert2/sweetalert2.min.js"></script>
        <script src="../plugins/password-requirement/js/jquery.passwordRequirements.min.js"></script>
        <script src="../dist/js/adminlte.min.js"></script>
        <script defer src="scripts/cookies/cookieconsent.js"></script>
        <script defer src="scripts/cookies/cookieconsent-init.js"></script>
        <script src="../plugins/jquery-validation/jquery.validate.min.js"></script>
        <script src="../plugins/jquery-validation/additional-methods.min.js"></script>
        <!-- Include jQuery and Bootstrap JS -->

        <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.3/dist/umd/popper.min.js"></script>
        <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>

        <script src="https://cdn.jsdelivr.net/npm/apexcharts@3.27.3/dist/apexcharts.min.js"></script>





        <script>
            // Function to show the toast
            function showToast() {
                const toast = document.getElementById('myToast');
                $(toast).toast('show'); // Manually trigger the toast
            }

            // Auto-trigger the toast on page load
            window.onload = function() {
                showToast();
            };
        </script>

        <script>
            document.addEventListener("DOMContentLoaded", function() {
                // Check if the modal has been closed previously
                if (!localStorage.getItem("modalClosed")) {
                    // Show the modal if not closed
                    document.getElementById("announcementModal").style.display = "block";
                }
            });

            function closeModal() {
                // Hide the modal
                document.getElementById("announcementModal").style.display = "none";
                // Set a flag in localStorage to indicate that the modal has been closed
                localStorage.setItem("modalClosed", "true");
            }
        </script>
        <!-- Scripts -->


        <script>
            // Data fetched from PHP
            var children1 = <?php echo json_encode($children_data['total_children1']); ?>;
            var children2 = <?php echo json_encode($children_data['total_children2']); ?>;
            var children3 = <?php echo json_encode($children_data['total_children3']); ?>;
            var teens1 = <?php echo json_encode($teens_data['total_teens1']); ?>;
            var teens2 = <?php echo json_encode($teens_data['total_teens2']); ?>;
            var teachers = <?php echo json_encode($teachers_data['total_teachers']); ?>;
            var pending = <?php echo json_encode($pending_data['total_pending']); ?>;
            var approved = <?php echo json_encode($approved_data['total_approved']); ?>;

            // Bar Chart for DTCE TEACHERS IDENTITY CARDS REPORT
            var options = {
                chart: {
                    type: 'bar',
                    height: 350
                },
                series: [{
                    name: 'Children (1-5)',
                    data: [children1]
                }, {
                    name: 'Children (6-8)',
                    data: [children2]
                }, {
                    name: 'Children (9-12)',
                    data: [children3]
                }, {
                    name: 'Teens (13-15)',
                    data: [teens1]
                }, {
                    name: 'Teens (16-above)',
                    data: [teens2]
                }, {
                    name: 'Teachers',
                    data: [teachers]
                }, {
                    name: 'Pending Reg.',
                    data: [pending]
                }, {
                    name: 'Approved Reg.',
                    data: [approved]
                }],
                xaxis: {
                    categories: ['Children (1-5)', 'Children (6-8)', 'Children (9-12)', 'Teens (13-15)', 'Teens (16-above)',
                        'Teachers', 'Pending Reg.', 'Approved Reg.'
                    ]
                },
                colors: ['#3bc0c3', '#1a2942', '#d1d7d9', '#ff4560', '#00e396', '#00e396', '#FFC107', '#28A745']
            };

            var chart = new ApexCharts(document.querySelector("#id-chart"), options);
            chart.render();

            // Line Chart for Monthly Junior Church Attendance Report
         // Pass PHP data to JavaScript
var approvedCount = <?php echo json_encode($approvedCount); ?>;
var pendingCount = <?php echo json_encode($pendingCount); ?>;
var totalCash = <?php echo json_encode($totalCash); ?>;

// Update Line Chart for Registrations
var options2 = {
    chart: {
        type: 'line',
        height: 350
    },
    series: [{
        name: 'Registrations',
        data: [approvedCount, pendingCount, totalCash] // Data for Approved, Pending, and Total Cash
    }],
    xaxis: {
        categories: ['Approved', 'Pending', 'Total Cash']
    },
    colors: ['#3bc0c3']
};

var chart2 = new ApexCharts(document.querySelector("#yearly-sales-chart"), options2);
chart2.render();
        </script>


        <script>
            document.addEventListener('DOMContentLoaded', function() {
                const toggle = document.getElementById('theme-toggle');
                const icon = document.getElementById('theme-icon');

                function applyDarkMode() {
                    document.body.classList.add('dark-mode');
                    document.body.classList.remove('light-mode');
                    if (icon) {
                        icon.classList.remove('fa-sun');
                        icon.classList.add('fa-moon');
                    }
                    localStorage.setItem('theme', 'dark');
                }

                function applyLightMode() {
                    document.body.classList.add('light-mode');
                    document.body.classList.remove('dark-mode');
                    if (icon) {
                        icon.classList.remove('fa-moon');
                        icon.classList.add('fa-sun');
                    }
                    localStorage.setItem('theme', 'light');
                }

                // Check and apply the saved theme
                if (localStorage.getItem('theme') === 'dark') {
                    applyDarkMode();
                } else {
                    applyLightMode();
                }

                // Toggle event listener
                if (toggle) {
                    toggle.addEventListener('click', function() {
                        if (document.body.classList.contains('dark-mode')) {
                            applyLightMode();
                        } else {
                            applyDarkMode();
                        }
                    });
                }
            });
        </script>
        <script>
            document.addEventListener("DOMContentLoaded", function() {
                // Function to update countdowns
                function updateCountdowns() {
                    const countdowns = document.querySelectorAll('.countdown');

                    countdowns.forEach(function(countdown) {
                        const eventDate = new Date(countdown.getAttribute('data-event-date')).getTime();
                        const now = new Date().getTime();
                        const distance = eventDate - now;

                        if (distance > 0) {
                            const days = Math.floor(distance / (1000 * 60 * 60 * 24));
                            const hours = Math.floor((distance % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60));
                            const minutes = Math.floor((distance % (1000 * 60 * 60)) / (1000 * 60));
                            const seconds = Math.floor((distance % (1000 * 60)) / 1000);

                            countdown.innerHTML = `
                        <div class="countdown-box">
                            ${days}<span>Days</span>
                        </div>
                        <div class="countdown-box">
                            ${hours}<span>Hours</span>
                        </div>
                        <div class="countdown-box">
                            ${minutes}<span>Minutes</span>
                        </div>
                        <div class="countdown-box">
                            ${seconds}<span>Seconds</span>
                        </div>
                    `;
                        } else {
                            countdown.innerHTML = "<p class='text-danger'>Event Started!</p>";
                        }
                    });
                }

                // Update countdowns every second
                setInterval(updateCountdowns, 1000);
                updateCountdowns(); // Initial call to display the countdown immediately
            });
        </script>
        <script>
            document.addEventListener('DOMContentLoaded', function() {
                // Initialize Bootstrap carousel if you haven't already included Bootstrap JS
                const carouselElement = document.getElementById('event-carousel');

                if (carouselElement) {
                    // Ensure Bootstrap's carousel plugin is initialized
                    new bootstrap.Carousel(carouselElement, {
                        interval: 5000, // Optional: time in ms between slides
                        ride: 'carousel' // Optional: ride the carousel
                    });
                }

                // Countdown Timer Functionality
                function updateCountdown() {
                    const countdowns = document.querySelectorAll('.countdown');
                    const now = new Date();

                    countdowns.forEach(countdown => {
                        const eventDate = new Date(countdown.getAttribute('data-event-date'));
                        const timeDifference = eventDate - now;

                        if (timeDifference > 0) {
                            const days = Math.floor(timeDifference / (1000 * 60 * 60 * 24));
                            const hours = Math.floor((timeDifference % (1000 * 60 * 60 * 24)) / (1000 * 60 *
                                60));
                            const minutes = Math.floor((timeDifference % (1000 * 60 * 60)) / (1000 * 60));
                            const seconds = Math.floor((timeDifference % (1000 * 60)) / 1000);

                            countdown.innerHTML = `
                    <div class="countdown-box">${days}<span>Days</span></div>
                    <div class="countdown-box">${hours}<span>Hours</span></div>
                    <div class="countdown-box">${minutes}<span>Minutes</span></div>
                    <div class="countdown-box">${seconds}<span>Seconds</span></div>
                `;
                        } else {
                            countdown.innerHTML = `<div class="countdown-box">Expired</div>`;
                        }
                    });
                }

                // Update countdown every second
                setInterval(updateCountdown, 1000);

                // Initial call to populate countdown on page load
                updateCountdown();
            });
            document.addEventListener('DOMContentLoaded', function() {
                const carouselElement = document.getElementById('event-carousel');

                if (carouselElement) {
                    new bootstrap.Carousel(carouselElement, {
                        interval: 5000, // Optional: time in ms between slides
                        ride: 'carousel' // Optional: ride the carousel
                    });
                }
            });
        </script>
        <script>
            $(document).ready(function() {
                $('#notificationDropdown').on('click', function() {
                    $.ajax({
                        url: 'fetch_notifications.php',
                        type: 'GET',
                        data: {
                            province: '<?php echo $_SESSION['pro']; ?>'
                        },
                        dataType: 'json',
                        success: function(data) {
                            console.log('Fetched notifications:', data);
                            let notificationList = $('#notificationList');
                            notificationList.empty();

                            if (data.length === 0) {
                                notificationList.append(
                                    '<div class="dropdown-item">No Notifications</div>');
                            } else {
                                data.forEach(notification => {
                                    let createdDate = new Date(notification.created_at);
                                    let formattedDate = formatDate(createdDate);
                                    let timeAgo = timeSince(createdDate);
                                    let unreadBadge = notification.is_read === 0 ?
                                        '<span class="badge badge-danger">Unread</span>' :
                                        '';

                                    notificationList.append(`
                            <a class="dropdown-item" href="read_notification.php?id=${notification.id}">
                                ${unreadBadge} ${notification.message}
                                <small class="text-muted">${formattedDate} (${timeAgo})</small>
                            </a>
                        `);
                                });
                            }

                            $('.badge-danger').text(data.length);
                        },
                        error: function(xhr, status, error) {
                            console.error('Error loading notifications:', error);
                        }
                    });
                });
            });

            function formatDate(date) {
                const options = {
                    day: 'numeric',
                    month: 'short',
                    year: 'numeric'
                };
                let day = date.getDate();
                let month = date.toLocaleString('default', {
                    month: 'short'
                });
                let suffix = day % 10 === 1 && day !== 11 ? 'st' :
                    day % 10 === 2 && day !== 12 ? 'nd' :
                    day % 10 === 3 && day !== 13 ? 'rd' : 'th';
                return `${day}${suffix} ${month}, ${date.getFullYear()}`;
            }

            function timeSince(date) {
                const seconds = Math.floor((new Date() - date) / 1000);
                let interval = Math.floor(seconds / 31536000);
                if (interval > 1) return interval + " years ago";
                interval = Math.floor(seconds / 2592000);
                if (interval > 1) return interval + " months ago";
                interval = Math.floor(seconds / 86400);
                if (interval > 1) return interval + " days ago";
                interval = Math.floor(seconds / 3600);
                if (interval > 1) return interval + " hours ago";
                interval = Math.floor(seconds / 60);
                if (interval > 1) return interval + " minutes ago";
                return seconds + " seconds ago";
            }
        </script>

        <!-- <script>
        document.addEventListener('DOMContentLoaded', function() {
            // Fetch data from the server
            fetch('fetch_virtual_account.php') // This endpoint returns data based on the session
                .then(response => response.json())
                .then(data => {
                    if (data.error) {
                        alert(data.error);
                    } else {
                        document.getElementById('account-number').textContent = data.account_number;
                        document.getElementById('bank-name').textContent = data.bank_name;
                        document.getElementById('balance').textContent = `$${data.balance.toFixed(2)}`;
                    }
                })
                .catch(error => console.error('Error fetching account data:', error));
        });
    </script> -->


        <!-- Other Scripts -->

</body>

</html>