<?php
require 'conn.php'; // Include database connection
session_start(); // Start session to access province if needed

function delete_record($conn, $rrr) {
    try {
        $conn->beginTransaction(); // Start transaction

        // Delete from all related tables using rrr as the linking key
        $deleteChildren = $conn->prepare("DELETE FROM children WHERE password = ?");
        $deleteTeens = $conn->prepare("DELETE FROM teens WHERE password = ?");
        $deleteTeachers = $conn->prepare("DELETE FROM teachers WHERE password = ?");
        $deleteReg = $conn->prepare("DELETE FROM registration WHERE password = ?");
        $deleteBank = $conn->prepare("DELETE FROM bank WHERE rrr = ?");
        $deleteSlip = $conn->prepare("DELETE FROM slip WHERE teller_number = ?");

        $deleteChildren->execute([$rrr]);
        $deleteTeens->execute([$rrr]);
        $deleteTeachers->execute([$rrr]);
        $deleteReg->execute([$rrr]);
        $deleteBank->execute([$rrr]);
        $deleteSlip->execute([$rrr]);

        $conn->commit(); // Commit all changes
        echo json_encode(['success' => true, 'message' => 'All associated records deleted successfully.']);
    } catch (PDOException $e) {
        $conn->rollBack(); // Rollback on error
        echo json_encode(['success' => false, 'message' => 'Error: ' . $e->getMessage()]);
    }
}

// Ensure request is valid
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['rrr'])) {
    $rrr = $_POST['rrr'];

    // Check if province condition is needed
    if (isset($_SESSION['pro'])) {
        $province = $_SESSION['pro'];
    } else {
        $province = null;
    }

    delete_record($conn, $rrr);
} else {
    echo json_encode(['success' => false, 'message' => 'Invalid request.']);
}
?>
