<?php
// Include database connection
include('conn.php');

// Fetch provinces based on selected region
if (isset($_POST['region'])) {
    $region = $_POST['region'];

    try {
        // Prepare query to fetch provinces sorted numerically based on the last number
        $sql = "SELECT DISTINCT province 
                FROM province 
                WHERE region = :region 
                ORDER BY CAST(SUBSTRING_INDEX(province, ' ', -1) AS UNSIGNED) ASC";

        $stmt = $conn->prepare($sql);

        // Bind the region parameter to the prepared statement
        $stmt->bindParam(':region', $region, PDO::PARAM_STR);

        // Execute the query
        $stmt->execute();

        // Fetch the results
        $provinces = [];
        while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
            $provinces[] = $row;
        }

        // Return provinces as JSON
        echo json_encode($provinces);

    } catch (PDOException $e) {
        // Handle any errors
        echo json_encode(["error" => "Error fetching provinces: " . $e->getMessage()]);
    }
}
?>
