<?php
// Include database connection
include('conn.php');

// Fetch regions based on selected zone
if (isset($_POST['zone'])) {
    $zone = $_POST['zone'];

    try {
        // Prepare query to fetch regions sorted numerically
        $sql = "SELECT DISTINCT region FROM province WHERE zone = :zone ORDER BY CAST(region AS UNSIGNED) ASC";
        $stmt = $conn->prepare($sql);

        // Bind the zone parameter to the prepared statement
        $stmt->bindParam(':zone', $zone, PDO::PARAM_STR);

        // Execute the query
        $stmt->execute();

        // Fetch the results
        $regions = [];
        while ($row = $stmt->fetch(PDO::FETCH_ASSOC)) {
            $regions[] = $row;
        }

        // Return regions as JSON
        echo json_encode($regions);

    } catch (PDOException $e) {
        // Handle any errors
        echo json_encode(["error" => "Error fetching regions: " . $e->getMessage()]);
    }
}
?>
